@@ -1,8 +1,9 @@
 /* FSNFunctions.h
  *  
- * Copyright (C) 2004 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2016 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
+ *         Riccardo Mottola <rm@gnu.org>
  * Date: March 2004
  *
  * This file is part of the GNUstep FSNode framework
@@ -39,4 +40,10 @@ NSArray *makePathsSelection(NSArray *selnodes);
 
 double myrintf(double a);
 
+void showAlertNoPermission(Class c, NSString *name);
+void showAlertInRecycler(Class c);
+void showAlertInvalidName(Class c);
+NSInteger showAlertExtensionChange(Class c, NSString *extension);
+void showAlertNameInUse(Class c, NSString *newname);
+
 #endif // FSN_FUNCTIONS_H
