@@ -1,6 +1,6 @@
 /* FSNIcon.m
  *  
- * Copyright (C) 2004-2013 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2016 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: March 2004
@@ -67,26 +67,25 @@ static NSImage *branchImage;
 {
   static BOOL initialized = NO;
 
-  if (initialized == NO) {
-    NSBundle *bundle = [NSBundle bundleForClass: [FSNodeRep class]];
-    NSString *imagepath = [bundle pathForResource: @"ArrowRight" ofType: @"tiff"];
+  if (initialized == NO)
+    {
+      if (desktopApp == nil)
+        {
+          NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
+          NSString *appName = [defaults stringForKey: @"DesktopApplicationName"];
+          NSString *selName = [defaults stringForKey: @"DesktopApplicationSelName"];
 
-    if (desktopApp == nil) {
-      NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
-      NSString *appName = [defaults stringForKey: @"DesktopApplicationName"];
-      NSString *selName = [defaults stringForKey: @"DesktopApplicationSelName"];
+          if (appName && selName)
+            {
+              Class desktopAppClass = [[NSBundle mainBundle] classNamed: appName];
+              SEL sel = NSSelectorFromString(selName);
+              desktopApp = [desktopAppClass performSelector: sel];
+            }
+        }
 
-      if (appName && selName) {
-		    Class desktopAppClass = [[NSBundle mainBundle] classNamed: appName];
-        SEL sel = NSSelectorFromString(selName);
-        desktopApp = [desktopAppClass performSelector: sel];
-      }
+      branchImage = [NSBrowserCell branchImage];
+      initialized = YES;
     }
-
-    branchImage = [[NSImage alloc] initWithContentsOfFile: imagepath];
-  
-    initialized = YES;
-  }
 }
 
 + (NSImage *)branchImage
@@ -94,6 +93,51 @@ static NSImage *branchImage;
   return branchImage;
 }
 
+/* we try to find a good host name.
+ * We try to find something different from localhost, if possibile without dots,
+ * else the first part of the qualified hostname gets taken */
++ (NSString *)getBestHostName
+{
+  NSHost *host = [NSHost currentHost];
+  NSString *hname;
+  NSRange range;
+  NSArray *hnames;
+
+  hnames = [host names];
+  if ([hnames count] > 0)
+    {
+      hname = [hnames objectAtIndex:0];
+
+      if ([hnames count] > 1)
+        {
+          NSUInteger i;
+
+          for (i = 0; i < [hnames count]; i++)
+            {
+              NSString *better;
+
+              better = [hnames objectAtIndex:i];
+              if (![better isEqualToString:@"localhost"])
+                {
+                  if ([hname isEqualToString:@"localhost"] || [hname isEqualToString:@"127.0.0.1"])
+                    hname = better;
+                  else if ([better rangeOfString:@"."].location == NSNotFound)
+                    hname = better;
+                }
+            }
+        }
+
+      range = [hname rangeOfString: @"."];
+      if (range.length != 0)
+        hname = [hname substringToIndex: range.location];
+    }
+  else
+    {
+      hname = @"unknown";
+    }
+  return hname;
+}
+
 - (id)initForNode:(FSNode *)anode
      nodeInfoType:(FSNInfoType)type
      extendedType:(NSString *)exttype
@@ -144,17 +188,13 @@ static NSImage *branchImage;
     hlightRect = NSIntegralRect(hlightRect);
     ASSIGN (highlightPath, [fsnodeRep highlightPathOfSize: hlightRect.size]);
         
-		if ([[node path] isEqual: path_separator()] && ([node isMountPoint] == NO)) {
-		  NSHost *host = [NSHost currentHost];
-		  NSString *hname = [host name];
-		  NSRange range = [hname rangeOfString: @"."];
+    if ([[node path] isEqual: path_separator()] && ([node isMountPoint] == NO))
+      {
+	NSString *hname;
 
-		  if (range.length != 0) {	
-			  hname = [hname substringToIndex: range.location];
-		  } 			
-      
-		  ASSIGN (hostname, hname);
-		} 
+	hname = [FSNIcon getBestHostName];
+        ASSIGN (hostname, hname);
+      } 
     
     label = [FSNTextCell new];
     [label setFont: lfont];
@@ -176,17 +216,17 @@ static NSImage *branchImage;
     }
     
     labelRect = NSZeroRect;
-    labelRect.size.width = [label uncuttedTitleLenght] + [fsnodeRep labelMargin];
-    labelRect.size.height = [fsnodeRep heighOfFont: [label font]];
+    labelRect.size.width = [label uncutTitleLenght] + [fsnodeRep labelMargin];
+    labelRect.size.height = [fsnodeRep heightOfFont: [label font]];
     labelRect = NSIntegralRect(labelRect);
 
     infoRect = NSZeroRect;
     if ((showType != FSNInfoNameType) && [[infolabel stringValue] length]) {
-      infoRect.size.width = [infolabel uncuttedTitleLenght] + [fsnodeRep labelMargin];
+      infoRect.size.width = [infolabel uncutTitleLenght] + [fsnodeRep labelMargin];
     } else {
       infoRect.size.width = labelRect.size.width;
     }
-    infoRect.size.height = [fsnodeRep heighOfFont: [infolabel font]];
+    infoRect.size.height = [fsnodeRep heightOfFont: [infolabel font]];
     infoRect = NSIntegralRect(infoRect);
 
     icnPosition = ipos;
@@ -282,7 +322,7 @@ static NSImage *branchImage;
   if (icnPosition == NSImageAbove) {
     float hlx, hly;
 
-    labelRect.size.width = [label uncuttedTitleLenght] + lblmargin;
+    labelRect.size.width = [label uncutTitleLenght] + lblmargin;
   
     if (labelRect.size.width >= frameRect.size.width) {
       labelRect.size.width = frameRect.size.width;
@@ -293,7 +333,7 @@ static NSImage *branchImage;
 
     if (showType != FSNInfoNameType) {
       if (hasinfo) {
-        infoRect.size.width = [infolabel uncuttedTitleLenght] + lblmargin;
+        infoRect.size.width = [infolabel uncutTitleLenght] + lblmargin;
       } else {
         infoRect.size.width = labelRect.size.width;
       }
@@ -351,7 +391,7 @@ static NSImage *branchImage;
       icnspacew += BRANCH_SIZE;
     }
     
-    labelRect.size.width = myrintf([label uncuttedTitleLenght] + lblmargin);
+    labelRect.size.width = myrintf([label uncutTitleLenght] + lblmargin);
     
     if (labelRect.size.width >= (frameRect.size.width - icnspacew)) {
       labelRect.size.width = (frameRect.size.width - icnspacew);
@@ -359,7 +399,7 @@ static NSImage *branchImage;
     
     if (showType != FSNInfoNameType) {
       if (hasinfo) {
-        infoRect.size.width = [infolabel uncuttedTitleLenght] + lblmargin;
+        infoRect.size.width = [infolabel uncutTitleLenght] + lblmargin;
       } else {
         infoRect.size.width = labelRect.size.width;
       }
@@ -666,47 +706,54 @@ static NSImage *branchImage;
 
 - (void)drawRect:(NSRect)rect
 {	 
-  if (isSelected) {
-    [[NSColor selectedControlColor] set];
-    [highlightPath fill];
-    
-    if (icnPosition != NSImageOnly) {
-      if (nameEdited == NO) {
-        NSFrameRect(labelRect);
-        NSRectFill(labelRect);  
-        [label drawWithFrame: labelRect inView: self];
-      }
-      
-      if ((showType != FSNInfoNameType) && [[infolabel stringValue] length]) {
-        [infolabel drawWithFrame: infoRect inView: self];
-      }
+  if (isSelected)
+    {
+      [[NSColor selectedControlColor] set];
+      [highlightPath fill];
+      if (nameEdited == NO)
+        {
+          NSFrameRect(labelRect);
+          NSRectFill(labelRect);  
+        }
     }
-  } else {
-    if (icnPosition != NSImageOnly) {
-      if (nameEdited == NO) {
-        [[container backgroundColor] set];
-        [label drawWithFrame: labelRect inView: self];
-      }
-      
-      if ((showType != FSNInfoNameType) && [[infolabel stringValue] length]) {
-        [infolabel drawWithFrame: infoRect inView: self];
-      }
+  else
+    {
+      if (nameEdited == NO)
+        {
+          [[container backgroundColor] set];
+        }
     }  
-  }
+  if (icnPosition != NSImageOnly)
+    {
+      if (nameEdited == NO)
+        {
+          [label drawWithFrame: labelRect inView: self];
+        }
+      
+      if ((showType != FSNInfoNameType) && [[infolabel stringValue] length])
+        {
+          [infolabel drawWithFrame: infoRect inView: self];
+        }
+    }
 
-	if (isLocked == NO) {	
-    if (isOpened == NO) {	
-      [drawicon compositeToPoint: icnPoint operation: NSCompositeSourceOver];
-    } else {
-      [drawicon dissolveToPoint: icnPoint fraction: 0.5];
+  if (isLocked == NO)
+    {	
+      if (isOpened == NO)
+        {
+          [drawicon compositeToPoint: icnPoint operation: NSCompositeSourceOver];
+        }
+      else
+        {
+          [drawicon dissolveToPoint: icnPoint fraction: 0.5];
+        }
+    }
+  else
+    {	
+      [drawicon dissolveToPoint: icnPoint fraction: 0.3];
     }
-	} else {						
-    [drawicon dissolveToPoint: icnPoint fraction: 0.3];
-	}
   
-  if (isLeaf == NO) {
-    [[isa branchImage] compositeToPoint: brImgBounds.origin operation: NSCompositeSourceOver];
-  }
+  if (isLeaf == NO)
+    [[object_getClass(self) branchImage] compositeToPoint: brImgBounds.origin operation: NSCompositeSourceOver];
 }
 
 
@@ -724,17 +771,13 @@ static NSImage *branchImage;
   drawicon = icon;
   DESTROY (selectedicon);
   
-  if ([[node path] isEqual: path_separator()] && ([node isMountPoint] == NO)) {
-    NSHost *host = [NSHost currentHost];
-    NSString *hname = [host name];
-    NSRange range = [hname rangeOfString: @"."];
+  if ([[node path] isEqual: path_separator()] && ([node isMountPoint] == NO))
+    { 
+      NSString *hname;
 
-    if (range.length != 0) {	
-      hname = [hname substringToIndex: range.location];
-    } 			
-      
-    ASSIGN (hostname, hname);
-  } 
+      hname = [FSNIcon getBestHostName];
+      ASSIGN (hostname, hname);
+    } 
   
   if (extInfoType) {
     [self setExtendedShowType: extInfoType];
@@ -766,12 +809,12 @@ static NSImage *branchImage;
 
 - (void)showSelection:(NSArray *)selnodes
 {
-  int i;
+  NSUInteger i;
     
   ASSIGN (node, [selnodes objectAtIndex: 0]);
   ASSIGN (selection, selnodes);
-  ASSIGN (selectionTitle, ([NSString stringWithFormat: @"%i %@", 
-                  [selection count], NSLocalizedString(@"elements", @"")]));
+  ASSIGN (selectionTitle, ([NSString stringWithFormat: @"%lu %@", 
+                                     (unsigned long)[selection count], NSLocalizedString(@"elements", @"")]));
   ASSIGN (icon, [fsnodeRep multipleSelectionIconOfSize: iconSize]);
   drawicon = icon;
   DESTROY (selectedicon);
@@ -831,17 +874,17 @@ static NSImage *branchImage;
 
   [infolabel setFont: infoFont];
 
-  labelRect.size.width = myrintf([label uncuttedTitleLenght] + lblmargin);
-  labelRect.size.height = myrintf([fsnodeRep heighOfFont: [label font]]);
+  labelRect.size.width = myrintf([label uncutTitleLenght] + lblmargin);
+  labelRect.size.height = myrintf([fsnodeRep heightOfFont: [label font]]);
   labelRect = NSIntegralRect(labelRect);
 
   infoRect = NSZeroRect;
   if ((showType != FSNInfoNameType) && [[infolabel stringValue] length]) {
-    infoRect.size.width = [infolabel uncuttedTitleLenght] + lblmargin;
+    infoRect.size.width = [infolabel uncutTitleLenght] + lblmargin;
   } else {
     infoRect.size.width = labelRect.size.width;
   }
-  infoRect.size.height = [fsnodeRep heighOfFont: infoFont];
+  infoRect.size.height = [fsnodeRep heightOfFont: infoFont];
   infoRect = NSIntegralRect(infoRect);
 
   [self tile];
@@ -883,8 +926,8 @@ static NSImage *branchImage;
   hlightRect.origin.y = 0;
   ASSIGN (highlightPath, [fsnodeRep highlightPathOfSize: hlightRect.size]); 
 
-  labelRect.size.width = [label uncuttedTitleLenght] + [fsnodeRep labelMargin];
-  labelRect.size.height = [fsnodeRep heighOfFont: [label font]];
+  labelRect.size.width = [label uncutTitleLenght] + [fsnodeRep labelMargin];
+  labelRect.size.height = [fsnodeRep heightOfFont: [label font]];
 
   [self tile];
 }
