@@ -1,8 +1,9 @@
 /* FSNIconsView.m
  *  
- * Copyright (C) 2004-2013 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2016 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
+ *         Riccardo Mottola <rm@gnu.org>
  * Date: March 2004
  *
  * This file is part of the GNUstep FSNode framework
@@ -216,7 +217,7 @@ static void GWHighlightFrameRect(NSRect aRect)
     highlightSize.height = iconSize + 4;
   }
 
-  labelSize.height = floor([fsnodeRep heighOfFont: labelFont]);
+  labelSize.height = floor([fsnodeRep heightOfFont: labelFont]);
   labelSize.width = [fsnodeRep labelWFactor] * labelTextSize;
 
   gridSize.height = highlightSize.height;
@@ -795,7 +796,7 @@ pp.y = NSMaxY(br) + 1; \
       }
     }
     
-    menu = [[NSMenu alloc] initWithTitle: NSLocalizedString(@"Open with", @"")];
+    menu = [[NSMenu alloc] initWithTitle: NSLocalizedStringFromTableInBundle(@"Open with", nil, [NSBundle bundleForClass:[self class]], @"")];
     apps = [[NSWorkspace sharedWorkspace] infoForExtension: firstext];
     app_enum = [[apps allKeys] objectEnumerator];
 
@@ -1167,13 +1168,13 @@ pp.y = NSMaxY(br) + 1; \
   }
 
   if ([ndpath isEqual: source]) {
-    if ([operation isEqual: @"NSWorkspaceMoveOperation"]
-              || [operation isEqual: @"NSWorkspaceDestroyOperation"]
+    if ([operation isEqual: NSWorkspaceMoveOperation]
+              || [operation isEqual: NSWorkspaceDestroyOperation]
               || [operation isEqual: @"GWorkspaceRenameOperation"]
-              || [operation isEqual: @"NSWorkspaceRecycleOperation"]
+              || [operation isEqual: NSWorkspaceRecycleOperation]
 			        || [operation isEqual: @"GWorkspaceRecycleOutOperation"]) {
       
-      if ([operation isEqual: @"NSWorkspaceRecycleOperation"]) {
+      if ([operation isEqual: NSWorkspaceRecycleOperation]) {
 		    files = [info objectForKey: @"origfiles"];
       }	
               
@@ -1191,17 +1192,17 @@ pp.y = NSMaxY(br) + 1; \
   }
 
   if ([ndpath isEqual: destination]
-          && ([operation isEqual: @"NSWorkspaceMoveOperation"]   
-              || [operation isEqual: @"NSWorkspaceCopyOperation"]
-              || [operation isEqual: @"NSWorkspaceLinkOperation"]
-              || [operation isEqual: @"NSWorkspaceDuplicateOperation"]
+          && ([operation isEqual: NSWorkspaceMoveOperation]   
+              || [operation isEqual: NSWorkspaceCopyOperation]
+              || [operation isEqual: NSWorkspaceLinkOperation]
+              || [operation isEqual: NSWorkspaceDuplicateOperation]
               || [operation isEqual: @"GWorkspaceCreateDirOperation"]
               || [operation isEqual: @"GWorkspaceCreateFileOperation"]
-              || [operation isEqual: @"NSWorkspaceRecycleOperation"]
+              || [operation isEqual: NSWorkspaceRecycleOperation]
               || [operation isEqual: @"GWorkspaceRenameOperation"]
 				      || [operation isEqual: @"GWorkspaceRecycleOutOperation"])) { 
     
-    if ([operation isEqual: @"NSWorkspaceRecycleOperation"]) {
+    if ([operation isEqual: NSWorkspaceRecycleOperation]) {
 		  files = [info objectForKey: @"files"];
     }	
 
@@ -1738,13 +1739,13 @@ pp.y = NSMaxY(br) + 1; \
 }
 
 - (BOOL)validatePasteOfFilenames:(NSArray *)names
-                       wasCutted:(BOOL)cutted
+                       wasCut:(BOOL)cut
 {
   NSString *nodePath = [node path];
   NSString *prePath = [NSString stringWithString: nodePath];
   NSString *basePath;
   
-	if ([names count] == 0) {
+  if ([names count] == 0) {
 		return NO;
   } 
 
@@ -1952,7 +1953,7 @@ pp.y = NSMaxY(br) + 1; \
 
     sc = (abs(xsc) >= abs(ysc)) ? xsc : ysc;
           
-    for (i = 0; i < abs(sc / margin); i++) {
+    for (i = 0; i < (int)fabsf(sc / margin); i++) {
       CREATE_AUTORELEASE_POOL (pool);
       NSDate *limit = [NSDate dateWithTimeIntervalSinceNow: 0.01];
       int x = (abs(xsc) >= i) ? (xsc > 0 ? margin : -margin) : 0;
@@ -2239,50 +2240,24 @@ pp.y = NSMaxY(br) + 1; \
 - (void)controlTextDidEndEditing:(NSNotification *)aNotification
 {
   FSNode *ednode = [nameEditor node];
-  BOOL writable = [ednode isWritable];
     
 #define CLEAREDITING \
   [self stopRepNameEditing]; \
   return 
  
-  if (writable == NO) {
-    /* check for broken symlink */ 
-    if ([ednode isLink] && ([ednode hasValidPath] == NO)) { 
-      BOOL iamRoot;
-      
-      #ifdef __WIN32__
-		    iamRoot = YES;
-	    #else
-		    iamRoot = (geteuid() == 0);
-	    #endif
-      
-      writable = (iamRoot || [[ednode owner] isEqual: NSUserName()]);          
-    }
-    
-    if (writable == NO) {
-      NSRunAlertPanel(NSLocalizedString(@"Error", @""), 
-            [NSString stringWithFormat: @"%@\"%@\"!\n", 
-                NSLocalizedString(@"You do not have write permission for ", @""), 
-                      [ednode name]], NSLocalizedString(@"Continue", @""), nil, nil);   
-      CLEAREDITING;
-    }
-  }
   
-  if (writable) {
-    if ([ednode isParentWritable] == NO) {
-      NSRunAlertPanel(NSLocalizedString(@"Error", @""), 
-            [NSString stringWithFormat: @"%@\"%@\"!\n", 
-                NSLocalizedString(@"You do not have write permission for ", @""), 
-                    [ednode parentName]], NSLocalizedString(@"Continue", @""), nil, nil);   
-      CLEAREDITING;
-
-    } else if ([ednode isSubnodeOfPath: [desktopApp trashPath]]) {
-      NSRunAlertPanel(NSLocalizedString(@"Error", @""), 
-              NSLocalizedString(@"You can't rename an object that is in the Recycler", @""), 
-              NSLocalizedString(@"Continue", @""), nil, nil);   
-      CLEAREDITING;
-
-    } else {
+    if ([ednode isParentWritable] == NO)
+      {
+	showAlertNoPermission([FSNode class], [ednode parentName]);
+	CLEAREDITING;
+      }
+    else if ([ednode isSubnodeOfPath: [desktopApp trashPath]])
+      {
+	showAlertInRecycler([FSNode class]);
+	CLEAREDITING;
+      }
+    else
+      {
       NSString *newname = [nameEditor stringValue];
       NSString *newpath = [[ednode parentPath] stringByAppendingPathComponent: newname];
       NSString *extension = [newpath pathExtension];
@@ -2291,43 +2266,35 @@ pp.y = NSMaxY(br) + 1; \
       NSArray *dirContents = [ednode subNodeNamesOfParent];
       NSMutableDictionary *opinfo = [NSMutableDictionary dictionary];
 
-      if (([newname length] == 0) || (range.length > 0)) {
-        NSRunAlertPanel(NSLocalizedString(@"Error", @""), 
-                  NSLocalizedString(@"Invalid name", @""), 
-                            NSLocalizedString(@"Continue", @""), nil, nil);   
-        CLEAREDITING;
-      }	
+      if (([newname length] == 0) || (range.length > 0))
+	{
+	  showAlertInvalidName([FSNode class]);
+	  CLEAREDITING;
+	}
 
       if (([extension length] 
-              && ([ednode isDirectory] && ([ednode isPackage] == NO)))) {
-        NSString *msg = NSLocalizedString(@"Are you sure you want to add the extension ", @"");
+              && ([ednode isDirectory] && ([ednode isPackage] == NO))))
+	{
+          if (showAlertExtensionChange([FSNode class], extension) == NSAlertDefaultReturn)
+            {
+              CLEAREDITING;
+            }
+	}
 
-        msg = [msg stringByAppendingFormat: @"\"%@\" ", extension];
-        msg = [msg stringByAppendingString: NSLocalizedString(@"to the end of the name?", @"")];
-        msg = [msg stringByAppendingString: NSLocalizedString(@"\nif you make this change, your folder may appear as a single file.", @"")];
+      if ([dirContents containsObject: newname])
+	{
+	  if ([newname isEqual: [ednode name]])
+	    {
+	      CLEAREDITING;
+	    }
+	  else
+	    {
+	      showAlertNameInUse([FSNode class], newname);
+	      CLEAREDITING;
+	    }
+	}
 
-        if (NSRunAlertPanel(@"", msg, 
-                            NSLocalizedString(@"Cancel", @""), 
-				                    NSLocalizedString(@"OK", @""), 
-                            nil) == NSAlertDefaultReturn) {
-          CLEAREDITING;
-        }
-      }
-
-      if ([dirContents containsObject: newname]) {
-        if ([newname isEqual: [ednode name]]) {
-          CLEAREDITING;
-        } else {
-          NSRunAlertPanel(NSLocalizedString(@"Error", @""), 
-            [NSString stringWithFormat: @"%@\"%@\" %@ ", 
-                NSLocalizedString(@"The name ", @""), 
-                newname, NSLocalizedString(@" is already in use!", @"")], 
-                              NSLocalizedString(@"Continue", @""), nil, nil);   
-          CLEAREDITING;
-        }
-      }
-
-	    [opinfo setObject: @"GWorkspaceRenameOperation" forKey: @"operation"];	
+      [opinfo setObject: @"GWorkspaceRenameOperation" forKey: @"operation"];	
       [opinfo setObject: [ednode path] forKey: @"source"];	
       [opinfo setObject: newpath forKey: @"destination"];	
       [opinfo setObject: [NSArray arrayWithObject: @""] forKey: @"files"];	
@@ -2335,7 +2302,6 @@ pp.y = NSMaxY(br) + 1; \
       [self stopRepNameEditing];
       [desktopApp performFileOperation: opinfo];
     }
-  }
 }
 
 @end
