@@ -1,6 +1,6 @@
 /* FSNTextCell.m
  *  
- * Copyright (C) 2004-2012 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2013 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: March 2004
@@ -26,32 +26,12 @@
 #import <AppKit/AppKit.h>
 #import "FSNTextCell.h"
 
-static SEL cutNameSel = NULL;
-static cutIMP cutName = NULL;
-
-static SEL cutDateSel = NULL;
-static cutIMP cutDate = NULL;
-
 
 @implementation FSNTextCell
 
-+ (void)initialize
-{
-  static BOOL initialized = NO;
-
-  if (initialized == NO) {
-    cutNameSel = @selector(cutTitle:toFitWidth:);
-    cutName = (cutIMP)[self instanceMethodForSelector: cutNameSel];    
-    cutDateSel = @selector(cutTitle:toFitWidth:);
-    cutDate = (cutIMP)[self instanceMethodForSelector: cutDateSel];    
-
-    initialized = YES;
-  }
-}
-
 - (void)dealloc
 {
-  RELEASE (uncuttedTitle);
+  RELEASE (uncutTitle);
   RELEASE (fontAttr);
   RELEASE (dots);
   RELEASE (icon);  
@@ -62,17 +42,15 @@ static cutIMP cutDate = NULL;
 {
   self = [super init];
 
-  if (self) {
-    ASSIGN (fontAttr, [NSDictionary dictionaryWithObject: [self font] 
-                                                  forKey: NSFontAttributeName]);
-    ASSIGN (dots, @"...");
-    dtslenght = [dots sizeWithAttributes: fontAttr].width; 
-    titlesize = NSMakeSize(0, 0);
-    icon = nil;
-    dateCell = NO;
-    cutTitleSel = cutNameSel;
-    cutTitle = cutName;    
-  }
+  if (self)
+    {
+      ASSIGN (fontAttr, [NSDictionary dictionaryWithObject: [self font]
+				      forKey: NSFontAttributeName]);
+      ASSIGN (dots, @"...");
+      titlesize = NSMakeSize(0, 0);
+      icon = nil;
+      dateCell = NO;
+    }
 
   return self;
 }
@@ -84,17 +62,13 @@ static cutIMP cutDate = NULL;
   c->fontAttr = [fontAttr copyWithZone: zone];
   c->dots = [dots copyWithZone: zone];
 
-  c->dtslenght = dtslenght;
   c->dateCell = dateCell;
   
-  if (uncuttedTitle) {
-    c->uncuttedTitle = [uncuttedTitle copyWithZone: zone];
+  if (uncutTitle) {
+    c->uncutTitle = [uncutTitle copyWithZone: zone];
   } else {
-    c->uncuttedTitle = nil;
+    c->uncutTitle = nil;
   }
-  
-  c->cutTitleSel = cutNameSel;
-  c->cutTitle = cutName;   
 
   RETAIN (icon);
 
@@ -112,8 +86,7 @@ static cutIMP cutDate = NULL;
   [super setFont: fontObj];
   ASSIGN (fontAttr, [NSDictionary dictionaryWithObject: [self font] 
                                                 forKey: NSFontAttributeName]);
-  titlesize = [[self stringValue] sizeWithAttributes: fontAttr]; 
-  dtslenght = [dots sizeWithAttributes: fontAttr].width;     
+  titlesize = [[self stringValue] sizeWithAttributes: fontAttr];   
 }
 
 - (void)setIcon:(NSImage *)icn
@@ -126,7 +99,7 @@ static cutIMP cutDate = NULL;
   return icon;
 }
 
-- (float)uncuttedTitleLenght
+- (float)uncutTitleLenght
 {
   return titlesize.width;
 }
@@ -134,14 +107,6 @@ static cutIMP cutDate = NULL;
 - (void)setDateCell:(BOOL)value
 {
   dateCell = value;
-
-  if (dateCell) {
-    cutTitleSel = cutDateSel;
-    cutTitle = cutDate; 
-  } else {
-    cutTitleSel = cutNameSel;
-    cutTitle = cutName;  
-  }
 }
 
 - (BOOL)isDateCell
@@ -152,12 +117,14 @@ static cutIMP cutDate = NULL;
 - (NSString *)cutTitle:(NSString *)title 
             toFitWidth:(float)width
 {
-  if ([title sizeWithAttributes: fontAttr].width > width) {
-    int tl = [title length];
+  int tl = [title length];
   
-    if (tl <= 5) {
+  if (tl <= 5)
+    {
       return dots;
-    } else {
+    }
+  else
+    {
       int fpto = (tl / 2) - 2;
       int spfr = fpto + 3;
       NSString *fp = [title substringToIndex: fpto];
@@ -188,7 +155,6 @@ static cutIMP cutDate = NULL;
       
       return dotted;
     }
-  }
   
   return title;
 }
@@ -196,54 +162,69 @@ static cutIMP cutDate = NULL;
 - (NSString *)cutDateTitle:(NSString *)title 
                 toFitWidth:(float)width
 {
-  if ([title sizeWithAttributes: fontAttr].width > width) {
-    int tl = [title length];
+  NSUInteger tl = [title length];
     
-    if (tl <= 5) {
+  if (tl <= 5)
+    {
       return dots;
-    } else {
+    }
+  else
+    {
       NSString *format = @"%b %d %Y";
       NSCalendarDate *date = [NSCalendarDate dateWithString: title
                                              calendarFormat: format];
-      if (date) {
-        NSString *descr;
+      if (date)
+        {
+          NSString *descr;
         
-        format = @"%m/%d/%y";
-        descr = [date descriptionWithCalendarFormat: format 
-                            timeZone: [NSTimeZone localTimeZone] locale: nil];
+          format = @"%m/%d/%y";
+          descr = [date descriptionWithCalendarFormat: format 
+                                             timeZone: [NSTimeZone localTimeZone] locale: nil];
+        
+          if ([descr sizeWithAttributes: fontAttr].width > width) {
+            return [self cutTitle: descr toFitWidth: width];
+          } else {
+            return descr;
+          }
         
-        if ([descr sizeWithAttributes: fontAttr].width > width) {
-          return [self cutTitle: descr toFitWidth: width];
-        } else {
-          return descr;
         }
-        
-      } else {
-        return [self cutTitle: title toFitWidth: width];
-      }
+      else
+        {
+          return [self cutTitle: title toFitWidth: width];
+        }
     }
-  }
   
   return title;
 }
 
 - (void)drawInteriorWithFrame:(NSRect)cellFrame 
-		                   inView:(NSView *)controlView
+                       inView:(NSView *)controlView
 {
   NSRect title_rect = cellFrame;
-  float textlenght = title_rect.size.width;
-  NSString *cuttitle;  
+  CGFloat textlength;
+  NSString *cutTitle;  
 
 #define MARGIN (2.0)
  
-  if (icon) {
-    textlenght -= ([icon size].width + (MARGIN * 2));
-  }
-  
-  textlenght -= MARGIN;
-  ASSIGN (uncuttedTitle, [self stringValue]);
-  cuttitle = (*cutTitle)(self, cutTitleSel, uncuttedTitle, textlenght);
-  [self setStringValue: cuttitle];        
+  textlength = title_rect.size.width - MARGIN;
+  if (icon)
+    textlength -= ([icon size].width + (MARGIN * 2));
+
+  ASSIGN (uncutTitle, [self stringValue]);
+  /* we calculate the reduced title only if necessary */
+  cutTitle = nil;
+  if ([uncutTitle sizeWithAttributes: fontAttr].width > textlength)
+    {
+      if (dateCell)
+        cutTitle = [self cutDateTitle:uncutTitle toFitWidth:textlength];
+      else
+        cutTitle = [self cutTitle:uncutTitle toFitWidth:textlength];
+      [self setStringValue: cutTitle];
+    }
+  else
+    {
+      [self setStringValue: uncutTitle];
+    }
 
   title_rect.size.height = titlesize.height;
   title_rect.origin.y += ((cellFrame.size.height - titlesize.height) / 2.0);
@@ -271,8 +252,10 @@ static cutIMP cutDate = NULL;
     [icon compositeToPoint: icon_rect.origin 
 	               operation: NSCompositeSourceOver];
   }
-  
-  [self setStringValue: uncuttedTitle];          
+
+  /* we reset the title to the orginal string */
+  if (cutTitle)
+    [self setStringValue: uncutTitle];          
 }
 
 - (BOOL)startTrackingAt:(NSPoint)startPoint inView:(NSView *)controlView
