@@ -1,6 +1,6 @@
 /* FSNode.m
  *  
- * Copyright (C) 2004-2012 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2016 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: March 2004
@@ -29,12 +29,13 @@
 #import "FSNodeRep.h"
 #import "FSNFunctions.h"
 
+
 @implementation FSNode
 
 - (void)dealloc
 {
   RELEASE (path);
-  RELEASE (relativePath);  
+  RELEASE (relativePath);
   RELEASE (name);  
   RELEASE (attributes);  
   RELEASE (fileType);
@@ -69,13 +70,16 @@
   self = [super init];
     
   if (self) {
+    NSString *lastPathComponent;
+    
     fsnodeRep = [FSNodeRep sharedInstance];
     fm = [NSFileManager defaultManager];
     ws = [NSWorkspace sharedWorkspace];
     
     parent = aparent;
     ASSIGN (relativePath, rpath);
-    ASSIGN (name, [relativePath lastPathComponent]);
+    lastPathComponent = [[relativePath lastPathComponent] retain];
+    name = nil;
     
     if (parent) {
       NSString *parentPath = [parent path];
@@ -84,7 +88,7 @@
         parentPath = @"";
       }
       ASSIGN (path, ([NSString stringWithFormat: @"%@%@%@", 
-                                      parentPath, path_separator(), name]));
+                                      parentPath, path_separator(), lastPathComponent]));
     } else {
       ASSIGN (path, relativePath);
     }
@@ -121,6 +125,14 @@
                                       
     attributes = [fm fileAttributesAtPath: path traverseLink: NO];
     RETAIN (attributes);
+
+    /* we localize only directories which could be special */
+    if ([self isDirectory])
+      ASSIGN (name, NSLocalizedStringFromTableInBundle(lastPathComponent, nil, [NSBundle bundleForClass:[self class]], @""));
+    else
+      ASSIGN (name, lastPathComponent);
+    
+    [lastPathComponent release];
   }
     
   return self;
@@ -557,34 +569,34 @@
     flags.unknown = 1;
   } 
 
-  ASSIGN (typeDescription, NSLocalizedString(@"symbolic link", @""));
+  ASSIGN (typeDescription, NSLocalizedStringFromTableInBundle(@"symbolic link", nil, [NSBundle bundleForClass:[self class]], @""));
 }
 
 - (NSString *)typeDescription
 {
   if (typeDescription == nil) {
     if ([self isPlain]) {
-      ASSIGN (typeDescription, NSLocalizedString(@"plain file", @""));
+      ASSIGN (typeDescription, NSLocalizedStringFromTableInBundle(@"plain file", nil, [NSBundle bundleForClass:[self class]], @""));
     } else if ([self isDirectory]) {
       if ([self isApplication]) {
-        ASSIGN (typeDescription, NSLocalizedString(@"application", @""));
+        ASSIGN (typeDescription, NSLocalizedStringFromTableInBundle(@"application", nil, [NSBundle bundleForClass:[self class]], @""));
       } else if ([self isPackage]) {
-        ASSIGN (typeDescription, NSLocalizedString(@"plain file", @""));
+        ASSIGN (typeDescription, NSLocalizedStringFromTableInBundle(@"package", nil, [NSBundle bundleForClass:[self class]], @""));
       } else if ([self isMountPoint]) {
-        ASSIGN (typeDescription, NSLocalizedString(@"mount point", @""));
+        ASSIGN (typeDescription, NSLocalizedStringFromTableInBundle(@"mount point", nil, [NSBundle bundleForClass:[self class]], @""));
       } else {
-        ASSIGN (typeDescription, NSLocalizedString(@"directory", @""));
+        ASSIGN (typeDescription, NSLocalizedStringFromTableInBundle(@"directory", nil, [NSBundle bundleForClass:[self class]], @""));
       }
     } else if ([self isLink]) {
-      ASSIGN (typeDescription, NSLocalizedString(@"symbolic link", @""));
+      ASSIGN (typeDescription, NSLocalizedStringFromTableInBundle(@"symbolic link", nil, [NSBundle bundleForClass:[self class]], @""));
     } else if ([self isSocket]) {
-      ASSIGN (typeDescription, NSLocalizedString(@"socket", @""));
+      ASSIGN (typeDescription, NSLocalizedStringFromTableInBundle(@"socket", nil, [NSBundle bundleForClass:[self class]], @""));
     } else if ([self isCharspecial]) {
-      ASSIGN (typeDescription, NSLocalizedString(@"character special", @""));
+      ASSIGN (typeDescription, NSLocalizedStringFromTableInBundle(@"character special", nil, [NSBundle bundleForClass:[self class]], @""));
     } else if ([self isBlockspecial]) {
-      ASSIGN (typeDescription, NSLocalizedString(@"block special", @""));
+      ASSIGN (typeDescription, NSLocalizedStringFromTableInBundle(@"block special", nil, [NSBundle bundleForClass:[self class]], @""));
     } else {
-      ASSIGN (typeDescription, NSLocalizedString(@"unknown", @""));
+      ASSIGN (typeDescription, NSLocalizedStringFromTableInBundle(@"unknown", nil, [NSBundle bundleForClass:[self class]], @""));
     }
   }
 
@@ -649,29 +661,14 @@
   return filesize;
 }
 
-#define ONE_KB 1024
-#define ONE_MB (ONE_KB * ONE_KB)
-#define ONE_GB (ONE_KB * ONE_MB)
 
 - (NSString *)sizeDescription
 {
   unsigned long long fsize = [self fileSize];
   NSString *sizeStr;
-  char *sign = "";
+
+  sizeStr = sizeDescription(fsize);
     
-  if (fsize == 1)
-    sizeStr = @"1 byte";
-  else if (fsize == 0)
-    sizeStr = @"0 bytes";
-  else if (fsize < (10 * ONE_KB))
-    sizeStr = [NSString stringWithFormat: @"%s%d bytes", sign, (long)fsize];
-  else if(fsize < (100 * ONE_KB))
-    sizeStr = [NSString stringWithFormat: @"%s%3.2f KB", sign, ((double)fsize / (double)(ONE_KB))];
-  else if(fsize < (100 * ONE_MB))
-    sizeStr = [NSString stringWithFormat: @"%s%3.2f MB", sign,((double)fsize / (double)(ONE_MB))];
-  else 
-    sizeStr = [NSString stringWithFormat:@"%s%3.2f GB", sign, ((double)fsize / (double)(ONE_GB))];
-  
   return sizeStr;
 }
 
@@ -878,10 +875,10 @@
   } 
 
   if ([self isSubnodeOfPath: source]) {
-    if ([operation isEqual: @"NSWorkspaceMoveOperation"]
-        || [operation isEqual: @"NSWorkspaceDestroyOperation"]
+    if ([operation isEqual: NSWorkspaceMoveOperation]
+        || [operation isEqual: NSWorkspaceDestroyOperation]
         || [operation isEqual: @"GWorkspaceRenameOperation"]
-			  || [operation isEqual: @"NSWorkspaceRecycleOperation"]
+			  || [operation isEqual: NSWorkspaceRecycleOperation]
 			  || [operation isEqual: @"GWorkspaceRecycleOutOperation"]
 			  || [operation isEqual: @"GWorkspaceEmptyRecyclerOperation"]) { 
       for (i = 0; i < [files count]; i++) {
@@ -896,11 +893,11 @@
   }
 
   if ([self isSubnodeOfPath: destination]) {
-    if ([operation isEqual: @"NSWorkspaceMoveOperation"]
-          || [operation isEqual: @"NSWorkspaceCopyOperation"]
-          || [operation isEqual: @"NSWorkspaceLinkOperation"]
-				  || [operation isEqual: @"NSWorkspaceRecycleOperation"]
-				  || [operation isEqual: @"GWorkspaceRecycleOutOperation"]) { 
+    if ([operation isEqual: NSWorkspaceMoveOperation]
+          || [operation isEqual: NSWorkspaceCopyOperation]
+          || [operation isEqual: NSWorkspaceLinkOperation]
+	|| [operation isEqual: NSWorkspaceRecycleOperation]
+	|| [operation isEqual: @"GWorkspaceRecycleOutOperation"]) { 
       for (i = 0; i < [files count]; i++) {
         NSString *fname = [files objectAtIndex: i];
         NSString *fpath = [destination stringByAppendingPathComponent: fname];
