@@ -1,6 +1,6 @@
 /* FSNodeRep.m
  *  
- * Copyright (C) 2004-2013 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2016 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  *         Riccardo Mottola <rm@gnu.org>
@@ -27,6 +27,8 @@
 
 #import <Foundation/Foundation.h>
 #import <AppKit/AppKit.h>
+#import <GNUstepGUI/GSTheme.h>
+
 #import "FSNodeRep.h"
 #import "FSNFunctions.h"
 #import "ExtendedInfo.h"
@@ -89,6 +91,20 @@ static FSNodeRep *shared = nil;
   }
 }
 
+/*
+ * Loads and caches named images
+ * Images coming from GSTheme need to be recached on a theme change
+ */
+- (void)cacheIcons
+{
+  [multipleSelIcon release];
+  multipleSelIcon = [[NSImage imageNamed:NSImageNameMultipleDocuments] retain];
+  [trashIcon release];
+  trashIcon = [[NSImage imageNamed:NSImageNameTrashEmpty] retain];
+  [trashFullIcon retain];
+  trashFullIcon = [[NSImage imageNamed:NSImageNameTrashFull] retain];
+}
+
 - (id)initSharedInstance
 {    
   self = [super init];
@@ -98,6 +114,7 @@ static FSNodeRep *shared = nil;
     NSString *imagepath;
     BOOL isdir;
     NSString *libraryDir;
+    NSNotificationCenter *nc;
     
     fm = [NSFileManager defaultManager];
     ws = [NSWorkspace sharedWorkspace];
@@ -106,21 +123,17 @@ static FSNodeRep *shared = nil;
     labelWFactor = LABEL_W_FACT;
     
     oldresize = [[NSUserDefaults standardUserDefaults] boolForKey: @"old_resize"];
-    
-    imagepath = [bundle pathForResource: @"MultipleSelection" ofType: @"tiff"];
-    multipleSelIcon = [[NSImage alloc] initWithContentsOfFile: imagepath]; 
-    imagepath = [bundle pathForResource: @"FolderOpen" ofType: @"tiff"];
+
+    /* images coming form GSTheme */
+    [self cacheIcons];
+
+    /* images for which we provide our own resources */
+    imagepath = [bundle pathForImageResource: @"FolderOpen"];
     openFolderIcon = [[NSImage alloc] initWithContentsOfFile: imagepath]; 
-    imagepath = [bundle pathForResource: @"HardDisk" ofType: @"tiff"];
+    imagepath = [bundle pathForImageResource: @"HardDisk"];
     hardDiskIcon = [[NSImage alloc] initWithContentsOfFile: imagepath]; 
-    imagepath = [bundle pathForResource: @"HardDiskOpen" ofType: @"tiff"];
+    imagepath = [bundle pathForImageResource: @"HardDiskOpen"];
     openHardDiskIcon = [[NSImage alloc] initWithContentsOfFile: imagepath]; 
-    imagepath = [bundle pathForResource: @"Workspace" ofType: @"tiff"];
-    workspaceIcon = [[NSImage alloc] initWithContentsOfFile: imagepath];
-    imagepath = [bundle pathForResource: @"Recycler" ofType: @"tiff"];
-    trashIcon = [[NSImage alloc] initWithContentsOfFile: imagepath]; 
-    imagepath = [bundle pathForResource: @"RecyclerFull" ofType: @"tiff"];
-    trashFullIcon = [[NSImage alloc] initWithContentsOfFile: imagepath];
     
     iconsCache = [NSMutableDictionary new];
     rootPath = path_separator();
@@ -152,11 +165,15 @@ static FSNodeRep *shared = nil;
     lockedPaths = [NSMutableArray new];	
     hiddenPaths = [NSArray new];
     volumes = [[NSMutableSet alloc] initWithCapacity: 1];
+    [self setVolumes:[ws mountedRemovableMedia]];
     reservedNames = [[NSMutableSet alloc] initWithCapacity: 1];
     
     [self loadExtendedInfoModules];
     
     systype = [[NSProcessInfo processInfo] operatingSystem];
+
+    /* we observe a theme change to re-cache icons */
+    [nc addObserver:self selector:@selector(themeDidActivate:) name:GSThemeDidActivateNotification object:nil];
   }
     
   return self;
@@ -168,7 +185,7 @@ static FSNodeRep *shared = nil;
   NSMutableArray *bundlesPaths;
   NSEnumerator *enumerator;
   NSMutableArray *loaded;
-  int i;
+  NSUInteger i;
   
   bundlesPaths = [NSMutableArray array];
 
@@ -240,6 +257,13 @@ static FSNodeRep *shared = nil;
   return bundleList;
 }
 
+- (void)themeDidActivate:(id)sender
+{
+  /* we clean the cache of theme-derived images */
+  [iconsCache removeAllObjects];
+  [self cacheIcons];
+}
+
 @end
 
 
@@ -260,7 +284,6 @@ static FSNodeRep *shared = nil;
   RELEASE (openFolderIcon);
   RELEASE (hardDiskIcon);
   RELEASE (openHardDiskIcon);
-  RELEASE (workspaceIcon);
   RELEASE (trashIcon);
   RELEASE (trashFullIcon);
         
@@ -288,7 +311,7 @@ static FSNodeRep *shared = nil;
   if (hiddenNames || hideSysFiles || [hiddenPaths count])
     {
       NSMutableArray *filteredNames = [NSMutableArray array];
-      int i;
+      NSUInteger i;
 
       for (i = 0; i < [fnames count]; i++)
 	{
@@ -332,7 +355,7 @@ static FSNodeRep *shared = nil;
   labelWFactor = f;
 }
 
-- (float)heighOfFont:(NSFont *)font
+- (float)heightOfFont:(NSFont *)font
 {
 //  return [font defaultLineHeightForFont];
   return ([font pointSize] * FONT_H_FACT);
@@ -465,7 +488,7 @@ static FSNodeRep *shared = nil;
 
 - (void)lockNodes:(NSArray *)nodes
 {
-	int i;
+  NSUInteger i;
 	  
 	for (i = 0; i < [nodes count]; i++) {
     NSString *path = [[nodes objectAtIndex: i] path];
@@ -507,67 +530,69 @@ static FSNodeRep *shared = nil;
 
 - (void)unlockNodes:(NSArray *)nodes
 {
-	int i;
+  NSUInteger i;
 	  
-	for (i = 0; i < [nodes count]; i++) {
-    NSString *path = [[nodes objectAtIndex: i] path];
+  for (i = 0; i < [nodes count]; i++)
+    {
+      NSString *path = [[nodes objectAtIndex: i] path];
 	
 		if ([lockedPaths containsObject: path]) {
 			[lockedPaths removeObject: path];
 		} 
-	}
+    }
 }
 
 - (void)unlockPaths:(NSArray *)paths
 {
-	int i;
+  NSUInteger i;
 	  
-	for (i = 0; i < [paths count]; i++) {
-    NSString *path = [paths objectAtIndex: i];
-	
-		if ([lockedPaths containsObject: path]) {
-			[lockedPaths removeObject: path];
-		} 
-	}
+  for (i = 0; i < [paths count]; i++)
+    {
+      NSString *path = [paths objectAtIndex: i];
+      
+      if ([lockedPaths containsObject: path])
+        {
+          [lockedPaths removeObject: path];
+        } 
+    }
 }
 
 - (BOOL)isNodeLocked:(FSNode *)node
 {
   NSString *path = [node path];
-	int i;  
+  NSUInteger i;  
   
-	if ([lockedPaths containsObject: path]) {
-		return YES;
-	}
+  if ([lockedPaths containsObject: path])
+    return YES;
 	
-	for (i = 0; i < [lockedPaths count]; i++) {
-		NSString *lpath = [lockedPaths objectAtIndex: i];
-	
-    if (isSubpathOfPath(lpath, path)) {
-			return YES;
-		}
-	}
-	
-	return NO;
+  for (i = 0; i < [lockedPaths count]; i++)
+    {
+      NSString *lpath = [lockedPaths objectAtIndex: i];
+      
+      if (isSubpathOfPath(lpath, path)) {
+        return YES;
+      }
+    }
+  
+  return NO;
 }
 
 - (BOOL)isPathLocked:(NSString *)path
 {
-	int i;  
+  NSUInteger i;  
   
-	if ([lockedPaths containsObject: path]) {
-		return YES;
-	}
-	
-	for (i = 0; i < [lockedPaths count]; i++) {
-		NSString *lpath = [lockedPaths objectAtIndex: i];
-	
-    if (isSubpathOfPath(lpath, path)) {
-			return YES;
-		}
-	}
-	
-	return NO;
+  if ([lockedPaths containsObject: path])
+    return YES;
+  
+  for (i = 0; i < [lockedPaths count]; i++)
+    {
+      NSString *lpath = [lockedPaths objectAtIndex: i];
+      
+      if (isSubpathOfPath(lpath, path))
+        return YES;
+    }
+  
+  return NO;
 }
 
 - (void)setVolumes:(NSArray *)vls
@@ -634,7 +659,7 @@ static FSNodeRep *shared = nil;
 {
   NSArray *deleted = [info objectForKey: @"deleted"];	
   NSArray *created = [info objectForKey: @"created"];	
-  int i;
+  NSUInteger i;
 
   if (usesThumbnails == NO) {
     return;
@@ -684,12 +709,13 @@ static FSNodeRep *shared = nil;
 - (NSArray *)availableExtendedInfoNames
 {
   NSMutableArray *names = [NSMutableArray array];
-  int i;
+  NSUInteger i;
   
-  for (i = 0; i < [extInfoModules count]; i++) {
-    id module = [extInfoModules objectAtIndex: i];
-    [names addObject: NSLocalizedString([module menuName], @"")];
-  }
+  for (i = 0; i < [extInfoModules count]; i++)
+    {
+      id module = [extInfoModules objectAtIndex: i];
+      [names addObject: [module menuName]];
+    }
   
   return names;
 }
@@ -697,372 +723,21 @@ static FSNodeRep *shared = nil;
 - (NSDictionary *)extendedInfoOfType:(NSString *)type
                              forNode:(FSNode *)anode
 {
-  int i;
+  NSUInteger i;
 
-  for (i = 0; i < [extInfoModules count]; i++) {
-    id module = [extInfoModules objectAtIndex: i];
-    NSString *mname = NSLocalizedString([module menuName], @"");
-  
-    if ([mname isEqual: type]) {
-      return [module extendedInfoForNode: anode];
+  for (i = 0; i < [extInfoModules count]; i++)
+    {
+      id module = [extInfoModules objectAtIndex: i];
+      NSString *mname = [module menuName];
+      
+      if ([mname isEqual: type])
+        {
+          return [module extendedInfoForNode: anode];
+        }
     }
-  }
   
   return nil;
 }
 
 @end
 
-
-@implementation NSWorkspace (mounting)
-
-- (NSArray *)mountedVolumes
-{
-  NSMutableArray *volumes = [NSMutableArray array];
-
-#ifdef HAVE_GETMNTINFO
-  /* most BSDs and derivatives inclusing Apple */
-  struct statfs *buf;
-  int i, count;
-  
-  count = getmntinfo(&buf, 0);
-  
-  for (i = 0; i < count; i++)
-    {
-      NSMutableDictionary *dict = [NSMutableDictionary dictionary];  
-  
-      [dict setObject: [NSString stringWithUTF8String: buf[i].f_mntfromname]
-	       forKey: @"name"]; 
-      [dict setObject: [NSString stringWithUTF8String: buf[i].f_mntonname]
-	       forKey: @"dir"]; 
-      [dict setObject: [NSString stringWithUTF8String: buf[i].f_fstypename]
-	       forKey: @"type"]; 
-
-      [volumes addObject: dict];
-    }
-#elif defined(HAVE_GETMNTENT) && defined(MNT_DIR)
-  /* most probably linux */
-  if ([[NSFileManager defaultManager] fileExistsAtPath: @"/etc/mtab"])
-    {
-      FILE *fp = fopen(MNTTAB, "r");
-      struct mntent	*mnt;
-
-      while ((mnt = getmntent(fp)) != NULL )
-	{ 
-	  NSMutableDictionary *dict = [NSMutableDictionary dictionary];
-
-	  [dict setObject: [NSString stringWithUTF8String: mnt->MNT_FSNAME]
-		   forKey: @"name"]; 
-	  [dict setObject: [NSString stringWithUTF8String: mnt->MNT_DIR]
-		   forKey: @"dir"];  
-	  [dict setObject: [NSString stringWithUTF8String: mnt->MNT_FSTYPE]
-		   forKey: @"type"];  
-
-	  [volumes addObject: dict];
-	}
-
-      fclose(fp);
-    
-    }
-  else
-    {
-      /* FIXME add something for Hurd */
-      
-    }       
-#endif
-
-  NSLog(@"Volumes %@", volumes);   
-  return volumes;
-}
-
-- (NSArray *)removableMediaPaths
-{
-  NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
-  NSDictionary *domain;
-  NSArray *removables;
-    
-  domain = [defaults persistentDomainForName: NSGlobalDomain];
-  removables = [domain objectForKey: @"GSRemovableMediaPaths"];
-
-  if (removables == nil) {
-    CREATE_AUTORELEASE_POOL(arp);
-    NSMutableDictionary *mdomain = [domain mutableCopy];  
-    unsigned int systype = [[NSProcessInfo processInfo] operatingSystem];
-  
-    switch (systype) {
-      case NSGNULinuxOperatingSystem:
-        removables = [NSArray arrayWithObjects: @"/mnt/floppy", @"/mnt/cdrom", nil];
-        break;
-
-      case NSBSDOperatingSystem:
-        removables = [NSArray arrayWithObjects: @"/cdrom", nil];
-        break;
-    
-      default:
-        break;
-    }
-    
-    if (removables) {
-      [mdomain setObject: removables forKey: @"GSRemovableMediaPaths"];
-      [defaults setPersistentDomain: mdomain forName: NSGlobalDomain];
-      [defaults synchronize];
-    }
-    
-    RELEASE (mdomain);
-    RELEASE (arp);
-  }
-    
-  return removables;
-}
-
-- (NSArray *)reservedMountNames
-{
-  NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
-  NSDictionary *domain;
-  NSArray *reserved;
-
-  [defaults synchronize];
-  domain = [defaults persistentDomainForName: NSGlobalDomain];
-  reserved = [domain objectForKey: @"GSReservedMountNames"];
-  
-  if (reserved == nil)
-    {
-      CREATE_AUTORELEASE_POOL(arp);
-      NSMutableDictionary *mdomain = [domain mutableCopy];  
-      unsigned int systype = [[NSProcessInfo processInfo] operatingSystem];
-  
-      switch(systype)
-	{
-	case NSGNULinuxOperatingSystem:
-	  reserved = [NSArray arrayWithObjects: @"proc", @"devpts", @"shm", 
-			      @"usbdevfs", @"devpts", 
-			      @"sysfs", @"tmpfs", @"procfs", nil];
-	  break;
-
-	case NSBSDOperatingSystem:
-	  reserved = [NSArray arrayWithObjects: @"devfs", @"procfs", nil];
-	  break;
-
-	case NSMACHOperatingSystem:
-	  reserved = [NSArray arrayWithObjects: @"devfs", @"fdesc", 
-			      @"<volfs>", nil];
-	  break;
-    
-	default:
-	  break;
-	}
-    
-      if (reserved)
-	{
-	  [mdomain setObject: reserved forKey: @"GSReservedMountNames"];
-	  [defaults setPersistentDomain: mdomain forName: NSGlobalDomain];
-	  [defaults synchronize];
-	}
-    
-      RELEASE (mdomain);
-      RELEASE (arp);
-    }
-
-  return reserved;
-}
-
-- (BOOL)getFileSystemInfoForPath:(NSString *)fullPath
-		                 isRemovable:(BOOL *)removableFlag
-		                  isWritable:(BOOL *)writableFlag
-		               isUnmountable:(BOOL *)unmountableFlag
-		                 description:(NSString **)description
-			                      type:(NSString **)fileSystemType
-{
-  return [self getFileSystemInfoForPath: fullPath
-		                 isRemovable: removableFlag
-		                  isWritable: writableFlag
-		               isUnmountable: unmountableFlag
-		                 description: description
-			                      type: fileSystemType
-                usingVolumesInfo: nil];
-}
-
-- (BOOL)getFileSystemInfoForPath:(NSString *)fullPath
-		                 isRemovable:(BOOL *)removableFlag
-		                  isWritable:(BOOL *)writableFlag
-		               isUnmountable:(BOOL *)unmountableFlag
-		                 description:(NSString **)description
-			                      type:(NSString **)fileSystemType
-                usingVolumesInfo:(NSArray *)info
-{
-  NSArray *mounted = ((info == nil) ? [self mountedVolumes] : info);
-  NSArray *removables = [self removableMediaPaths];
-  int i;
-
-  for (i = 0; i < [mounted count]; i++) {
-    NSDictionary *dict = [mounted objectAtIndex: i];
-    NSString *mountPoint = [dict objectForKey: @"dir"];
-    NSString *fsType = [dict objectForKey: @"type"];
-  
-    if ([mountPoint isEqual: fullPath]) {  
-      *removableFlag = [removables containsObject: mountPoint];
-      *writableFlag = [[NSFileManager defaultManager] isWritableFileAtPath: fullPath];
-      *unmountableFlag = YES;
-      *description = fsType;
-      *fileSystemType = fsType;
-
-      return YES;
-    }
-  }
-  
-  return NO;
-}
-
-- (NSArray *)mountedLocalVolumePaths
-{
-  NSMutableArray *mpoints = [NSMutableArray array];
-  NSArray *mounted = [self mountedVolumes];
-  NSArray *reserved = [self reservedMountNames];
-  unsigned i;
-
-  for (i = 0; i < [mounted count]; i++)
-    {
-      NSDictionary *dict = [mounted objectAtIndex: i];
-
-      if ([reserved containsObject: [dict objectForKey: @"name"]] == NO) {
-	[mpoints addObject: [dict objectForKey: @"dir"]];
-      }
-    }
-  
-  return mpoints;
-}
-
-- (NSArray *)mountedRemovableMedia
-{
-  NSMutableArray *mpoints = [NSMutableArray array];
-  NSArray *mounted = [self mountedVolumes];
-  NSArray *removables = [self removableMediaPaths];
-  NSArray *reserved = [self reservedMountNames];
-  NSMutableArray *names = [NSMutableArray array];  
-  unsigned i;
-
-  for (i = 0; i < [mounted count]; i++) {
-    NSDictionary *dict = [mounted objectAtIndex: i];
-    NSString *name = [dict objectForKey: @"name"];
-    NSString *dir = [dict objectForKey: @"dir"];
-
-    if (([reserved containsObject: name] == NO) 
-                        && [removables containsObject: dir]) {
-      [mpoints addObject: dir];
-    }
-  }
-
-  for (i = 0; i < [mpoints count]; i++) {
-    BOOL removableFlag;
-    BOOL writableFlag;
-    BOOL unmountableFlag;
-    NSString *description;
-    NSString *fileSystemType;
-    NSString *name = [mpoints objectAtIndex: i];
-
-    if ([self getFileSystemInfoForPath: name
-		              isRemovable: &removableFlag
-		              isWritable: &writableFlag
-		              isUnmountable: &unmountableFlag
-		              description: &description
-		              type: &fileSystemType
-      usingVolumesInfo: mounted] && removableFlag) {
-	    [names addObject: name];
-	  }
-  }
-
-  return names;
-}
-
-- (NSArray *)mountNewRemovableMedia
-{
-  NSArray *removables = [self removableMediaPaths];
-  NSArray *mountedMedia = [self mountedRemovableMedia]; 
-  NSMutableArray *willMountMedia = [NSMutableArray array];
-  NSMutableArray *newlyMountedMedia = [NSMutableArray array];
-  int i;
-
-  for (i = 0; i < [removables count]; i++) {
-    NSString *removable = [removables objectAtIndex: i];
-    
-    if ([mountedMedia containsObject: removable] == NO) {
-      [willMountMedia addObject: removable];
-    }
-  }  
-  
-  for (i = 0; i < [willMountMedia count]; i++) {
-    NSString *media = [willMountMedia objectAtIndex: i];
-    NSTask *task = [NSTask launchedTaskWithLaunchPath: @"mount"
-                                arguments: [NSArray arrayWithObject: media]];
-      
-    if (task) {
-      [task waitUntilExit];
-      
-      if ([task terminationStatus] == 0) {
-        NSDictionary *userinfo = [NSDictionary dictionaryWithObject: media 
-                                                      forKey: @"NSDevicePath"];
-
-        [[self notificationCenter] postNotificationName: NSWorkspaceDidMountNotification
-                                  object: self
-                                userInfo: userinfo];
-
-        [newlyMountedMedia addObject: media];
-      }
-    }
-  }
-
-  return newlyMountedMedia;
-}
-
-- (BOOL)unmountAndEjectDeviceAtPath:(NSString *)path
-{
-  unsigned int systype = [[NSProcessInfo processInfo] operatingSystem];
-  NSArray	*volumes = [self mountedLocalVolumePaths];
-
-  if ([volumes containsObject: path]) {
-    NSDictionary *userinfo;
-    NSTask *task;
-
-    userinfo = [NSDictionary dictionaryWithObject: path forKey: @"NSDevicePath"];
-
-    [[self notificationCenter] postNotificationName: NSWorkspaceWillUnmountNotification
-				                object: self
-				              userInfo: userinfo];
-
-    task = [NSTask launchedTaskWithLaunchPath: @"umount"
-				                            arguments: [NSArray arrayWithObject: path]];
-
-    if (task) {
-      [task waitUntilExit];
-      if ([task terminationStatus] != 0) {
-	      return NO;
-	    } 
-    } else {
-      return NO;
-    }
-
-    [[self notificationCenter] postNotificationName: NSWorkspaceDidUnmountNotification
-				                object: self
-				              userInfo: userinfo];
-
-    if (systype == NSGNULinuxOperatingSystem) {
-      [NSTask launchedTaskWithLaunchPath: @"eject"
-				                              arguments: [NSArray arrayWithObject: path]];
-    }
-    
-    return YES;
-  }
-  
-  return NO;
-}
-
-@end
-
-
-
-
-
-
-
-
-
