@@ -1,6 +1,6 @@
 /* FSNodeRepIcons.m
  *  
- * Copyright (C) 2005-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2005-2016 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  *         Riccardo Mottola
@@ -134,14 +134,12 @@ static unsigned char darkerLUT[256] = {
       if ([node isApplication])
 	{
 	  key = nodepath;
-
 	}
       else if (([node isMountPoint] && [volumes containsObject: nodepath])
 	       || [volumes containsObject: nodepath])
 	{
 	  key = @"disk";
 	  baseIcon = hardDiskIcon;
-
 	}
       else if ([node isPackage] == NO)
 	{
@@ -156,32 +154,65 @@ static unsigned char darkerLUT[256] = {
 	      /* we may have more than one folder icon */
 	      key = nodepath;
 	    }
-	}   
-    
+	}
+      else
+        {
+          /* a bundle */
+          key = nodepath;
+        }
+
       if (key != nil)
 	{
 	  icon = [self cachedIconOfSize: size forKey: key];
     
 	  if (icon == nil)
 	    {
-	      if (baseIcon == nil)
+              if (baseIcon == nil)
+                baseIcon = [ws iconForFile: nodepath];
+
+              if (baseIcon == nil)
+                {
+                  NSLog(@"no WS icon for %@", nodepath);
+                }
+	      if ([node isLink])
 		{
-		  baseIcon = [ws iconForFile: nodepath];
+		  NSImage *linkIcon;
+
+		  linkIcon = [NSImage imageNamed:@"common_linkCursor"];
+		  baseIcon = [baseIcon copy];
+		  [baseIcon lockFocus];
+		  [linkIcon compositeToPoint:NSMakePoint(0,0) operation:NSCompositeSourceOver];
+		  [baseIcon unlockFocus];
+		  [baseIcon autorelease];
 		}
-    
+  
 	      icon = [self cachedIconOfSize: size forKey: key addBaseIcon: baseIcon];
 	    }
 	}
     }  
-    
-  if (icon == nil)
+  else
     { // NOT DIRECTORY
+      NSString *realPath;
+
+      realPath = [nodepath stringByResolvingSymlinksInPath];
       if (usesThumbnails)
 	{
-	  icon = [self thumbnailForPath: nodepath];
+	  icon = [self thumbnailForPath: realPath];
       
 	  if (icon) {
 	    NSSize icnsize = [icon size];
+
+	    if ([node isLink])
+	      {
+		NSImage *linkIcon;
+		
+		linkIcon = [NSImage imageNamed:@"common_linkCursor"];
+		icon = [icon copy];
+		[icon lockFocus];
+		[linkIcon compositeToPoint:NSMakePoint(0,0) operation:NSCompositeSourceOver];
+		[icon unlockFocus];
+		[icon autorelease];
+	      }	    
       
 	    if ((icnsize.width > size) || (icnsize.height > size))
 	      {
@@ -189,12 +220,13 @@ static unsigned char darkerLUT[256] = {
 	      }  
 	  }
 	}
-    
+      // no thumbnail found
       if (icon == nil)
 	{
-	  NSString *ext = [[nodepath pathExtension] lowercaseString];
+          NSString *linkKey;
+	  NSString *ext = [[realPath pathExtension] lowercaseString];
       
-	  if (ext && ([ext isEqual: @""] == NO))
+	  if (ext && [ext length])
 	    {
 	      key = ext;
 	    }
@@ -202,29 +234,49 @@ static unsigned char darkerLUT[256] = {
 	    {
 	      key = @"unknown";
 	    }
-      
-	  icon = [self cachedIconOfSize: size forKey: key];
-
+          linkKey = nil;
+          if ([node isLink])
+            {
+              linkKey = [key stringByAppendingString:@"_linked"];
+              icon = [self cachedIconOfSize: size forKey: linkKey];
+            }
+          else
+            {
+              icon = [self cachedIconOfSize: size forKey: key];
+            }
+          
 	  if (icon == nil)
 	    {
-	      baseIcon = [ws iconForFile: nodepath];
-	      icon = [self cachedIconOfSize: size forKey: key addBaseIcon: baseIcon];
+              // we look up the cache, but only in the full size to composite later
+              baseIcon = [self cachedIconOfSize: 48 forKey: key];
+              if (baseIcon == nil)
+                baseIcon = [ws iconForFile: nodepath];
+
+	      if ([node isLink])
+		{
+		  NSImage *linkIcon;
+
+		  linkIcon = [NSImage imageNamed:@"common_linkCursor"];
+		  baseIcon = [baseIcon copy];
+		  [baseIcon lockFocus];
+		  [linkIcon compositeToPoint:NSMakePoint(0,0) operation:NSCompositeSourceOver];
+		  [baseIcon unlockFocus];
+		  [baseIcon autorelease];
+                  icon = [self cachedIconOfSize: size forKey: linkKey addBaseIcon: baseIcon];
+		}
+              else
+                {
+                  icon = [self cachedIconOfSize: size forKey: key addBaseIcon: baseIcon];
+                }
 	    }
 	}      
     }      
 
   if (icon == nil)
     {
-      NSSize icnsize;
-    
-      icon = [NSImage imageNamed: @"Unknown"];
-      icnsize = [icon size];
-
-      if ((icnsize.width > size) || (icnsize.height > size)){
-	icon = [self resizedIcon: icon ofSize: size];
-      }  
+      NSLog(@"Warning: No icon found for %@", nodepath);
     }
-  
+
   return icon;
 }
 
@@ -325,16 +377,6 @@ static unsigned char darkerLUT[256] = {
   return icon;
 }
 
-- (NSImage *)workspaceIconOfSize:(int)size
-{
-  NSSize icnsize = [workspaceIcon size];
-
-  if ((icnsize.width > size) || (icnsize.height > size)) {
-    return [self resizedIcon: workspaceIcon ofSize: size];
-  }  
-  
-  return workspaceIcon;
-}
 
 - (NSImage *)trashIconOfSize:(int)size
 {
