@@ -1,6 +1,6 @@
 /* MDKWindow.m
  *  
- * Copyright (C) 2006-2013 Free Software Foundation, Inc.
+ * Copyright (C) 2006-2016 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@fibernet.ro>
  * Date: December 2006
@@ -45,9 +45,8 @@
 #define CELLS_HEIGHT (28.0)
 #define ICNSIZE 24
 
-#if !defined(OPEN_MAX) || OPEN_MAX > 255
-#define OPEN_MAX 10
-#endif
+/* defines the maximum number of files to open before issuing a dialog */
+#define MAX_FILES_TO_OPEN_DIALOG 8
 
 
 BOOL isDotFile(NSString *path);
@@ -544,12 +543,12 @@ static NSString *nibName = @"MDKWindow";
   NSArray *usedAttributes = [self usedAttributes];
 
   if ([usedAttributes count] < [attributes count]) {
-    int index = [attrViews indexOfObjectIdenticalTo: view];  
+    NSUInteger index = [attrViews indexOfObjectIdenticalTo: view];  
     MDKAttribute *attr = [self firstUnusedAttribute];
     MDKAttributeView *attrview = [[MDKAttributeView alloc] initInWindow: self];
-    int count;
-    int attrcount;
-    int i;
+    NSUInteger count;
+    NSUInteger attrcount;
+    NSUInteger i;
 
     [attr setInUse: YES];
     [attrview setAttribute: attr];
@@ -1543,12 +1542,13 @@ static NSString *nibName = @"MDKWindow";
   NSUInteger count = [selected count];
   NSUInteger i;
 
-  if (count > OPEN_MAX) {
+  if (count > MAX_FILES_TO_OPEN_DIALOG) {
     NSString *msg1 = NSLocalizedString(@"Are you sure you want to open", @"");
     NSString *msg2 = NSLocalizedString(@"items?", @"");
   
     if (NSRunAlertPanel(nil,
-                [NSString stringWithFormat: @"%@ %i %@", msg1, count, msg2],
+                [NSString stringWithFormat: @"%@ %lu %@",
+                          msg1, (unsigned long) count, msg2],
                 NSLocalizedString(@"Cancel", @""),
                 NSLocalizedString(@"Yes", @""),
                 nil)) {
@@ -1663,7 +1663,7 @@ static NSString *nibName = @"MDKWindow";
     images = [NSMutableArray new];
     
     for (i = 0; i < IMAGES; i++) {
-      NSString *imname = [NSString stringWithFormat: @"anim-logo-%d", i];
+      NSString *imname = [NSString stringWithFormat: @"anim-logo-%lu", i];
       NSString *impath = [bundle pathForResource: imname ofType: @"tiff"];
       NSImage *image = [[NSImage alloc] initWithContentsOfFile: impath];
       
