@@ -1,6 +1,6 @@
 /* mdextractor.m
  *  
- * Copyright (C) 2006-2011 Free Software Foundation, Inc.
+ * Copyright (C) 2006-2013 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@dtedu.net>
  * Date: February 2006
@@ -1342,8 +1342,8 @@ do { \
 
   /* only to avoid a compiler warning */
   if (0) {
-    NSLog(user_db_schema);
-    NSLog(user_db_schema_tmp);
+    NSLog(@"%@", user_db_schema);
+    NSLog(@"%@", user_db_schema_tmp);
   }
 
   return YES;
@@ -1653,23 +1653,27 @@ void setUpdating(BOOL value)
 
 BOOL isDotFile(NSString *path)
 {
-  int len = ([path length] - 1);
-  unichar c;
-  int i;
-  
-  for (i = len; i >= 0; i--) {
-    c = [path characterAtIndex: i];
-    
-    if (c == '.') {
-      if ((i > 0) && ([path characterAtIndex: (i - 1)] == '/')) {
-        return YES;
-      }
+  NSArray *components;
+  NSEnumerator *e;
+  NSString *c;
+  BOOL found;
+
+  if (path == nil)
+    return NO;
+
+  found = NO;
+  components = [path pathComponents];
+  e = [components objectEnumerator];
+  while ((c = [e nextObject]) && !found)
+    {
+      if (([c length] > 0) && ([c characterAtIndex:0] == '.'))
+	found = YES;
     }
-  }
-  
-  return NO;  
+
+  return found;  
 }
 
+
 BOOL subPathOfPath(NSString *p1, NSString *p2)
 {
   int l1 = [p1 length];
