@@ -1,6 +1,6 @@
 /* Dock.m
  *  
- * Copyright (C) 2005-2012 Free Software Foundation, Inc.
+ * Copyright (C) 2005-2016 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: January 2005
@@ -35,6 +35,19 @@
 #define MIN_ICN_SIZE 16
 #define ICN_INCR 4
 
+/* small category to access NSNUmericSearch through a selector */
+
+@interface NSString (NumericSort)
+- (NSComparisonResult)numericCompare:(NSString *)s;
+@end
+
+@implementation NSString (NumericSort)
+- (NSComparisonResult)numericCompare:(NSString *)s
+{
+  return [self compare:s options:NSNumericSearch];
+}
+@end
+
 @implementation Dock
 
 - (void)dealloc
@@ -95,7 +108,7 @@
     if (appsdict) {
       NSArray *indexes = [appsdict allKeys];
     
-      indexes = [indexes sortedArrayUsingSelector: @selector(compare:)];
+      indexes = [indexes sortedArrayUsingSelector: @selector(numericCompare:)];
     
       for (i = 0; i < [indexes count]; i++) {
         NSNumber *index = [indexes objectAtIndex: i];
@@ -225,7 +238,7 @@
 
 - (DockIcon *)iconForApplicationName:(NSString *)name
 {
-  int i;
+  NSUInteger i;
   
   for (i = 0; i < [icons count]; i++) {
     DockIcon *icon = [icons objectAtIndex: i];
@@ -255,7 +268,7 @@
 
 - (DockIcon *)trashIcon
 {
-  int i;
+  NSUInteger i;
   
   for (i = 0; i < [icons count]; i++) {
     DockIcon *icon = [icons objectAtIndex: i];
@@ -270,7 +283,7 @@
 
 - (DockIcon *)iconContainingPoint:(NSPoint)p
 {
-  int i;
+  NSUInteger i;
   
   for (i = 0; i < [icons count]; i++) {
     DockIcon *icon = [icons objectAtIndex: i];
@@ -436,10 +449,10 @@
   NSView *view = [self superview];
   NSRect scrrect = [[NSScreen mainScreen] frame];
   int oldIcnSize = iconSize;
-  float maxheight = scrrect.size.height;
+  CGFloat maxheight = scrrect.size.height;
   NSRect icnrect = NSZeroRect;  
   NSRect rect = NSZeroRect;
-  int i;
+  NSUInteger i;
 
   iconSize = MAX_ICN_SIZE;
   
@@ -507,7 +520,7 @@
 {
   NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];	
   NSMutableDictionary *dict = [NSMutableDictionary dictionary];
-  int i;  
+  NSUInteger i;  
 
   [defaults setObject: [NSNumber numberWithInt: style]
                forKey: @"dockstyle"];
@@ -556,7 +569,7 @@
 	NSString *source = [info objectForKey: @"source"];	  
 	NSString *destination = [info objectForKey: @"destination"];	 
 	NSArray *files = [info objectForKey: @"files"];	 
-  int i, count;
+  NSUInteger i, count;
   
   if ([operation isEqual: NSWorkspaceMoveOperation]
         || [operation isEqual: NSWorkspaceDestroyOperation]
@@ -609,7 +622,7 @@
     
     if ([basePath isEqual: trashPath]) {
       NSArray *subNodes = [node subNodes];
-      int count = [subNodes count];
+      NSUInteger count = [subNodes count];
     
       for (i = 0; i < [subNodes count]; i++) {
         if ([[subNodes objectAtIndex: i] isReserved]) {
@@ -631,7 +644,7 @@
   NSString *path = [info objectForKey: @"path"];
     
   if ([event isEqual: @"GWWatchedPathDeleted"]) {
-    int i;
+    NSUInteger i;
 
     for (i = 0; i < [icons count]; i++) {
       DockIcon *icon = [icons objectAtIndex: i];
@@ -651,7 +664,7 @@
     
   } else if ([event isEqual: @"GWFileDeletedInWatchedDirectory"]) {
     NSArray *files = [info objectForKey: @"files"];
-    int i;
+    NSUInteger i;
     
     for (i = 0; i < [files count]; i++) {
       NSString *fname = [files objectAtIndex: i];
@@ -698,7 +711,7 @@
       DockIcon *icon = [self trashIcon];  
       FSNode *node = [icon node];
       NSArray *subNodes = [node subNodes];
-      int i;
+      NSUInteger i;
 
       for (i = 0; i < [subNodes count]; i++) {
         if ([[subNodes objectAtIndex: i] isReserved] == NO) {
@@ -714,7 +727,7 @@
 
 - (void)unselectOtherReps:(id)arep
 {
-  int i;
+  NSUInteger i;
   
   for (i = 0; i < [icons count]; i++) {
     DockIcon *icon = [icons objectAtIndex: i];    
@@ -733,7 +746,7 @@
 - (void)setBackgroundColor:(NSColor *)acolor
 {
   NSColor *hlgtcolor = [acolor highlightWithLevel: 0.2];
-  int i;
+  NSUInteger i;
   
   for (i = 0; i < [icons count]; i++)
     [[icons objectAtIndex: i] setHighlightColor: hlgtcolor];
@@ -778,7 +791,7 @@
   icon = [self iconContainingPoint: location];
                  
   if (icon) {
-    int index = [icons indexOfObjectIdenticalTo: icon];
+    NSUInteger index = [icons indexOfObjectIdenticalTo: icon];
         
     if (dndSourceIcon && ([sender draggingSource] == dndSourceIcon)) {
       if (icon != dndSourceIcon) {
@@ -805,7 +818,7 @@
         FSNode *node = [FSNode nodeWithPath: path];
       
         if ([node isApplication] && ([icon isSpecialIcon] == NO)) {
-          int i;
+          NSUInteger i;
           
           for (i = 0; i < [icons count]; i++) {
             if ([[[icons objectAtIndex: i] node] isEqualToNode: node]) {
@@ -870,7 +883,7 @@
   }
     
   if (icon) {
-    int index = [icons indexOfObjectIdenticalTo: icon];
+    NSUInteger index = [icons indexOfObjectIdenticalTo: icon];
 
     if (dndSourceIcon && ([sender draggingSource] == dndSourceIcon)) {
       if ((icon != dndSourceIcon) && ([icon isSpecialIcon] == NO)) {
@@ -915,7 +928,7 @@
     }   
   }
 
-	return NSDragOperationNone;
+  return NSDragOperationNone;
 }
 
 - (void)draggingExited:(id <NSDraggingInfo>)sender
@@ -978,7 +991,7 @@
         if ([node isApplication]) {
           if ((icon == nil) || (icon && ([icon isTrashIcon] == NO))) {
             BOOL duplicate = NO;
-            int i;
+            NSUInteger i;
 
             for (i = 0; i < [icons count]; i++) {
               DockIcon *icon = [icons objectAtIndex: i];
