@@ -1,6 +1,6 @@
 /* GWDesktopManager.m
  *  
- * Copyright (C) 2005-2013 Free Software Foundation, Inc.
+ * Copyright (C) 2005-2016 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: January 2005
@@ -31,6 +31,7 @@
 #import "GWorkspace.h"
 #import "GWViewersManager.h"
 #import "TShelf/TShelfWin.h"
+#import "Thumbnailer/GWThumbnailer.h"
 
 #define RESV_MARGIN 10
 
@@ -394,11 +395,6 @@ static GWDesktopManager *desktopManager = nil;
   [desktopView stopRepNameEditing];
 }
 
-- (void)deselectInSpatialViewers
-{
-  [[gworkspace viewersManager] selectedSpatialViewerChanged: nil];
-}
-
 - (void)addWatcherForPath:(NSString *)path
 {
   [gworkspace addWatcherForPath: path];
@@ -450,6 +446,38 @@ static GWDesktopManager *desktopManager = nil;
   NS_ENDHANDLER
 }
 
+- (void)makeThumbnails:(id)sender
+{
+  NSString *path;
+
+  path = [dskNode path];
+  path = [path stringByResolvingSymlinksInPath];
+  if (path)
+    {
+      Thumbnailer *t;
+      
+      t = [Thumbnailer sharedThumbnailer];
+      [t makeThumbnails:path];
+      [t release];
+    }
+}
+
+- (void)removeThumbnails:(id)sender
+{
+  NSString *path;
+
+  path = [dskNode path];
+  path = [path stringByResolvingSymlinksInPath];
+  if (path)
+    {
+      Thumbnailer *t;
+      
+      t = [Thumbnailer sharedThumbnailer];
+      [t removeThumbnails:path];
+      [t release];
+    }
+}
+
 - (void)fileSystemWillChange:(NSNotification *)notif
 {
   NSDictionary *opinfo = (NSDictionary *)[notif object];  
@@ -472,11 +500,16 @@ static GWDesktopManager *desktopManager = nil;
     [NSApp terminate: self];
   }
 
-  if ([dskNode involvedByFileOperation: opinfo]) {
-    [[self desktopView] nodeContentsDidChange: opinfo];  
-  }
+  /* update the desktop view, but only if it is visible */
+  if ([self isActive] && [dskNode involvedByFileOperation: opinfo])
+    {
+      [[self desktopView] nodeContentsDidChange: opinfo];  
+    }
   
-  [dock nodeContentsDidChange: opinfo];  
+  if ([self dockActive])
+    {
+      [dock nodeContentsDidChange: opinfo];
+    }
 }
 
 - (void)watcherNotification:(NSNotification *)notif
@@ -485,21 +518,26 @@ static GWDesktopManager *desktopManager = nil;
   NSString *path = [info objectForKey: @"path"];
   NSString *event = [info objectForKey: @"event"];
   
-  if ([path isEqual: [dskNode path]]) {
-    if ([event isEqual: @"GWWatchedPathDeleted"]) {
-      NSRunAlertPanel(nil, 
-                      NSLocalizedString(@"The Desktop directory has been deleted! Quiting now!", @""), 
-                      NSLocalizedString(@"OK", @""), 
-                      nil, 
-                      nil);                                     
-      [NSApp terminate: self];
-
-    } else {
-      [[self desktopView] watchedPathChanged: info];
+  if ([path isEqual: [dskNode path]])
+    {
+      if ([event isEqual: @"GWWatchedPathDeleted"])
+        {
+          NSRunAlertPanel(nil, 
+                          NSLocalizedString(@"The Desktop directory has been deleted! Quiting now!", @""), 
+                          NSLocalizedString(@"OK", @""), 
+                          nil, 
+                          nil);                                     
+          [NSApp terminate: self];
+        }
+      /* update the desktop view, but only if active */
+      else if ([self isActive]) 
+        {
+          [[self desktopView] watchedPathChanged: info];
+        }
     }
-  }
-
-  [dock watchedPathChanged: info];  
+  /* update the dock, if active */
+  if ([self dockActive])
+    [dock watchedPathChanged: info];  
 }
 
 - (void)thumbnailsDidChangeInPaths:(NSArray *)paths
@@ -555,6 +593,12 @@ static GWDesktopManager *desktopManager = nil;
   }
 }
 
+- (void)unlockVolumeAtPath:(NSString *)volpath
+{
+  [fsnodeRep unlockPaths: [NSArray arrayWithObject: volpath]];
+  [[self desktopView] unlockVolumeAtPath: volpath];
+}
+
 - (void)mountedVolumesDidChange
 {
   [[self desktopView] showMountedVolumes];
@@ -656,7 +700,7 @@ static GWDesktopManager *desktopManager = nil;
 - (void)openSelectionInNewViewer:(BOOL)newv
 {
   NSArray *selreps = [desktopView selectedReps];
-  int i;
+  NSUInteger i;
     
   for (i = 0; i < [selreps count]; i++) {
     FSNode *node = [[selreps objectAtIndex: i] node];
@@ -885,7 +929,7 @@ static GWDesktopManager *desktopManager = nil;
   if (active) {
     int count = [volinfo count];
     BOOL changed = NO;
-    int i;
+    NSUInteger i;
     
     for (i = 0; i < count; i++) {
       NSMutableDictionary *dict = [volinfo objectAtIndex: i];
