@@ -1,6 +1,6 @@
 /* GWDesktopView.m
  *  
- * Copyright (C) 2005-2012 Free Software Foundation, Inc.
+ * Copyright (C) 2005-2016 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  *         Riccardo Mottola <rm@gnu.org>
@@ -147,6 +147,11 @@
   }
 }
 
+- (void)unlockVolumeAtPath:(NSString *)path
+{
+  [self checkLockedReps];
+}
+
 - (void)showMountedVolumes
 {
   NSArray *rvpaths = [[NSWorkspace sharedWorkspace] mountedRemovableMedia];
@@ -350,9 +355,9 @@
   if (iconPosition == NSImageAbove) {  
     hlightRect.origin.x = ceil((gridSize.width - hlightRect.size.width) / 2);   
     if (infoType != FSNInfoNameType) {
-      hlightRect.origin.y = floor([fsnodeRep heighOfFont: labelFont] * 2 - 2);
+      hlightRect.origin.y = floor([fsnodeRep heightOfFont: labelFont] * 2 - 2);
     } else { 
-      hlightRect.origin.y = floor([fsnodeRep heighOfFont: labelFont]);
+      hlightRect.origin.y = floor([fsnodeRep heightOfFont: labelFont]);
     }
   } else {
     hlightRect.origin.x = 0;
@@ -539,7 +544,7 @@
 
     if (infoType == FSNInfoExtendedType) {
       DESTROY (extInfoType);
-      dskinfo = [dskinfo objectForKey: @"ext_info_type"];
+      entry = [dskinfo objectForKey: @"ext_info_type"];
 
       if (entry) {
         NSArray *availableTypes = [fsnodeRep availableExtendedInfoNames];
@@ -744,17 +749,16 @@
   [win makeMainWindow];
   [win makeKeyWindow];
   
-  if ([theEvent modifierFlags] != NSShiftKeyMask) {
-    selectionMask = NSSingleSelectionMask;
-    selectionMask |= FSNCreatingSelectionMask;
-		[self unselectOtherReps: nil];
-    selectionMask = NSSingleSelectionMask;
+  if ([theEvent modifierFlags] != NSShiftKeyMask)
+    {
+      selectionMask = NSSingleSelectionMask;
+      selectionMask |= FSNCreatingSelectionMask;
+      [self unselectOtherReps: nil];
+      selectionMask = NSSingleSelectionMask;
     
-    DESTROY (lastSelection);
-    [self selectionDidChange];
-    
-    [manager deselectInSpatialViewers];
-	}
+      DESTROY (lastSelection);
+      [self selectionDidChange];
+    }
 }
 
 #define SUPPORTS_XOR ((GNUSTEP_GUI_MAJOR_VERSION > 0)		\
@@ -1108,11 +1112,11 @@ static void GWHighlightFrameRect(NSRect aRect)
   }
 
   if ([[node path] isEqual: source]
-        && ([operation isEqual: @"NSWorkspaceMoveOperation"]
-            || [operation isEqual: @"NSWorkspaceDestroyOperation"]
-            || [operation isEqual: @"GWorkspaceRenameOperation"]
-			      || [operation isEqual: @"NSWorkspaceRecycleOperation"]
-			      || [operation isEqual: @"GWorkspaceRecycleOutOperation"])) {
+      && ([operation isEqual: NSWorkspaceMoveOperation]
+	  || [operation isEqual: NSWorkspaceDestroyOperation]
+	  || [operation isEqual: @"GWorkspaceRenameOperation"]
+	  || [operation isEqual: NSWorkspaceRecycleOperation]
+	  || [operation isEqual: @"GWorkspaceRecycleOutOperation"])) {
     for (i = 0; i < [files count]; i++) {
       NSString *fname = [files objectAtIndex: i];
       FSNode *subnode = [FSNode nodeWithRelativePath: fname parent: node];
@@ -1135,13 +1139,13 @@ static void GWHighlightFrameRect(NSRect aRect)
   }
 
   if ([[node path] isEqual: destination]
-          && ([operation isEqual: @"NSWorkspaceMoveOperation"]   
-              || [operation isEqual: @"NSWorkspaceCopyOperation"]
-              || [operation isEqual: @"NSWorkspaceLinkOperation"]
-              || [operation isEqual: @"NSWorkspaceDuplicateOperation"]
-              || [operation isEqual: @"GWorkspaceCreateDirOperation"]
-              || [operation isEqual: @"GWorkspaceRenameOperation"]
-				      || [operation isEqual: @"GWorkspaceRecycleOutOperation"])) { 
+      && ([operation isEqual: NSWorkspaceMoveOperation]   
+	  || [operation isEqual: NSWorkspaceCopyOperation]
+	  || [operation isEqual: NSWorkspaceLinkOperation]
+	  || [operation isEqual: NSWorkspaceDuplicateOperation]
+	  || [operation isEqual: @"GWorkspaceCreateDirOperation"]
+	  || [operation isEqual: @"GWorkspaceRenameOperation"]
+	  || [operation isEqual: @"GWorkspaceRecycleOutOperation"])) { 
     for (i = 0; i < [files count]; i++) {
       NSString *fname = [files objectAtIndex: i];
       FSNode *subnode = [FSNode nodeWithRelativePath: fname parent: node];
@@ -1382,19 +1386,17 @@ static void GWHighlightFrameRect(NSRect aRect)
 
 - (void)selectionDidChange
 {
-	if (!(selectionMask & FSNCreatingSelectionMask)) {
-    NSArray *selection = [self selectedNodes];
+  if (!(selectionMask & FSNCreatingSelectionMask))
+    {
+      NSArray *selection = [self selectedNodes];
 		
-    if ([selection count] == 0) {
-      selection = [NSArray arrayWithObject: node];
-    } else {
-      [manager deselectInSpatialViewers];
+      if ([selection count] == 0)
+        selection = [NSArray arrayWithObject: node];
+      
+      ASSIGN (lastSelection, selection);
+      [desktopApp selectionChanged: selection];
+      [self updateNameEditor];
     }
-
-    ASSIGN (lastSelection, selection);
-    [desktopApp selectionChanged: selection];
-    [self updateNameEditor];
-	}
 }
 
 - (void)openSelectionInNewViewer:(BOOL)newv
@@ -1403,18 +1405,18 @@ static void GWHighlightFrameRect(NSRect aRect)
 }
 
 - (BOOL)validatePasteOfFilenames:(NSArray *)names
-                       wasCutted:(BOOL)cutted
+                       wasCut:(BOOL)cut
 {
   NSMutableArray *sourcePaths = [names mutableCopy];
   NSString *basePath;
   NSString *nodePath = [node path];
   NSString *prePath = [NSString stringWithString: nodePath];
-	int count = [names count];
+  NSUInteger count = [names count];
   int i;
   
   AUTORELEASE (sourcePaths);
 
-	if (count == 0) {
+  if (count == 0) {
 		return NO;
   } 
 
