@@ -19,20 +19,23 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
 
-#ifndef COMPLETION_FIELD_H
-#define COMPLETION_FIELD_H
-
-#include <AppKit/NSTextView.h>
+#import <AppKit/NSTextView.h>
 
 @interface CompletionField : NSTextView 
 {
   id fm;
+  id controller;
 }
 
 @end
 
-#endif // COMPLETION_FIELD_H
+
+@interface NSObject (CompletionField)
+
+- (void)completionFieldDidEndLine:(id)afield;
+
+@end
