@@ -62,6 +62,12 @@ static NSString *nibName = @"RunExternal";
       [win setDelegate: self];
       [win setFrameUsingName: @"run_external"];
       [win setInitialFirstResponder: cfield];
+
+      [win setTitle:NSLocalizedString(@"Run", @"")];
+      [titleLabel setStringValue:NSLocalizedString(@"Run", @"")];
+      [secondLabel setStringValue:NSLocalizedString(@"Type the command to execute:", @"")];
+      [okButt setTitle:NSLocalizedString(@"OK", @"")];
+      [cancelButt setTitle:NSLocalizedString(@"Cancel", @"")];
       
       fm = [NSFileManager defaultManager];
     }
