@@ -1,8 +1,9 @@
 /* GWViewerIconsPath.m
  *  
- * Copyright (C) 2004-2012 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2016 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
+ *         Riccardo Mottola <rm@gnu.org>
  * Date: July 2004
  *
  * This file is part of the GNUstep GWorkspace application
@@ -286,7 +287,7 @@
     highlightSize.height = iconSize + 4;
   }
 
-  labelSize.height = myrintf([fsnodeRep heighOfFont: labelFont]);
+  labelSize.height = myrintf([fsnodeRep heightOfFont: labelFont]);
   gridSize.height = highlightSize.height + labelSize.height;
 }
 
@@ -570,7 +571,7 @@
 - (NSArray *)selectedNodes
 {
   NSMutableArray *selectedNodes = [NSMutableArray array];
-  int i;
+  NSUInteger i;
   
   for (i = 0; i < [icons count]; i++) {
     FSNIcon *icon = [icons objectAtIndex: i];
@@ -592,7 +593,7 @@
 - (NSArray *)selectedPaths
 {
   NSMutableArray *selectedPaths = [NSMutableArray array];
-  int i, j;
+  NSUInteger i, j;
   
   for (i = 0; i < [icons count]; i++) {
     FSNIcon *icon = [icons objectAtIndex: i];
@@ -615,11 +616,12 @@
 
 - (void)checkLockedReps
 {
-  int i;
+  NSUInteger i;
   
-  for (i = 0; i < [icons count]; i++) {
-    [[icons objectAtIndex: i] checkLocked];
-  }
+  for (i = 0; i < [icons count]; i++)
+    {
+      [[icons objectAtIndex: i] checkLocked];
+    }
 }
 
 - (FSNSelectionMask)selectionMask
@@ -673,11 +675,11 @@
     FSNode *ednode = [editIcon node];
     NSString *nodeDescr = [editIcon shownInfo];
     NSRect icnr = [editIcon frame];
-    float centerx = icnr.origin.x + (icnr.size.width / 2);    
+    CGFloat centerx = icnr.origin.x + (icnr.size.width / 2);    
     NSRect labr = [editIcon labelRect];
     int margin = [fsnodeRep labelMargin];
-    float bw = [self bounds].size.width - EDIT_MARGIN;
-    float edwidth = 0.0; 
+    CGFloat bw = [self bounds].size.width - EDIT_MARGIN;
+    CGFloat edwidth = 0.0; 
     NSRect edrect;
 
     [editIcon setNameEdited: YES];
@@ -780,50 +782,21 @@
 - (void)controlTextDidEndEditing:(NSNotification *)aNotification
 {
   FSNode *ednode = [nameEditor node];
-  BOOL writable = [ednode isWritable];
 
-#define CLEAREDITING \
-  [self stopRepNameEditing]; \
-  return 
-  
-  if (writable == NO) {
-    /* check for broken symlink */     
-    if ([ednode isLink] && ([ednode hasValidPath] == NO)) { 
-      BOOL iamRoot;
-      
-      #ifdef __WIN32__
-		    iamRoot = YES;
-	    #else
-		    iamRoot = (geteuid() == 0);
-	    #endif
-      
-      writable = (iamRoot || [[ednode owner] isEqual: NSUserName()]);          
+  if ([ednode isParentWritable] == NO)
+    {
+      showAlertNoPermission([FSNode class], [ednode parentName]);
+      [self updateNameEditor];
+      return;
     }
-    
-    if (writable == NO) {
-      NSRunAlertPanel(NSLocalizedString(@"Error", @""), 
-            [NSString stringWithFormat: @"%@\"%@\"!\n", 
-                NSLocalizedString(@"You do not have write permission for ", @""), 
-                      [ednode name]], NSLocalizedString(@"Continue", @""), nil, nil);   
-      CLEAREDITING;
-    }
-  }
-  
-  if (writable) {    
-    if ([ednode isParentWritable] == NO) {
-      NSRunAlertPanel(NSLocalizedString(@"Error", @""), 
-            [NSString stringWithFormat: @"%@\"%@\"!\n", 
-                NSLocalizedString(@"You do not have write permission for ", @""), 
-                    [ednode parentName]], NSLocalizedString(@"Continue", @""), nil, nil);   
-      CLEAREDITING;
-
-    } else if ([ednode isSubnodeOfPath: [[GWorkspace gworkspace] trashPath]]) {
-      NSRunAlertPanel(NSLocalizedString(@"Error", @""), 
-              NSLocalizedString(@"You can't rename an object that is in the Recycler", @""), 
-              NSLocalizedString(@"Continue", @""), nil, nil);   
-      CLEAREDITING;
-
-    } else {
+  if ([ednode isSubnodeOfPath: [[GWorkspace gworkspace] trashPath]])
+    {
+      showAlertInRecycler([FSNode class]);
+      [self updateNameEditor];
+      return;
+    } 
+  else
+    {
       NSString *newname = [nameEditor stringValue];
       NSString *newpath = [[ednode parentPath] stringByAppendingPathComponent: newname];
       NSString *extension = [newpath pathExtension];
@@ -831,52 +804,47 @@
       NSRange range = [newname rangeOfCharacterFromSet: notAllowSet];
       NSArray *dirContents = [ednode subNodeNamesOfParent];
       NSMutableDictionary *opinfo = [NSMutableDictionary dictionary];
-
-      if (([newname length] == 0) || (range.length > 0)) {
-        NSRunAlertPanel(NSLocalizedString(@"Error", @""), 
-                  NSLocalizedString(@"Invalid name", @""), 
-                            NSLocalizedString(@"Continue", @""), nil, nil);   
-        CLEAREDITING;
-      }	
-
+      
+      if (([newname length] == 0) || (range.length > 0))
+        {
+	  showAlertInvalidName([FSNode class]);
+	  [self updateNameEditor];
+          return;
+        }	
+      
       if (([extension length] 
-              && ([ednode isDirectory] && ([ednode isPackage] == NO)))) {
-        NSString *msg = NSLocalizedString(@"Are you sure you want to add the extension ", @"");
-
-        msg = [msg stringByAppendingFormat: @"\"%@\" ", extension];
-        msg = [msg stringByAppendingString: NSLocalizedString(@"to the end of the name?", @"")];
-        msg = [msg stringByAppendingString: NSLocalizedString(@"\nif you make this change, your folder may appear as a single file.", @"")];
-
-        if (NSRunAlertPanel(@"", msg, 
-                            NSLocalizedString(@"Cancel", @""), 
-				                    NSLocalizedString(@"OK", @""), 
-                            nil) == NSAlertDefaultReturn) {
-          CLEAREDITING;
+           && ([ednode isDirectory] && ([ednode isPackage] == NO))))
+        {
+          if (showAlertExtensionChange([FSNode class], extension) == NSAlertDefaultReturn)
+            {
+	      [self updateNameEditor];
+	      return;
+	    }
         }
-      }
-
-      if ([dirContents containsObject: newname]) {
-        if ([newname isEqual: [ednode name]]) {
-          CLEAREDITING;
-        } else {
-          NSRunAlertPanel(NSLocalizedString(@"Error", @""), 
-            [NSString stringWithFormat: @"%@\"%@\" %@ ", 
-                NSLocalizedString(@"The name ", @""), 
-                newname, NSLocalizedString(@" is already in use!", @"")], 
-                              NSLocalizedString(@"Continue", @""), nil, nil);   
-          CLEAREDITING;
+      
+      if ([dirContents containsObject: newname])
+        {
+          if ([newname isEqual: [ednode name]])
+            {
+              [self updateNameEditor];
+              return;
+            }
+          else
+            {
+              showAlertNameInUse([FSNode class], newname);
+              [self updateNameEditor];
+              return;
+            }
         }
-      }
-
-	    [opinfo setObject: @"GWorkspaceRenameOperation" forKey: @"operation"];	
+      
+      [opinfo setObject: @"GWorkspaceRenameOperation" forKey: @"operation"];	
       [opinfo setObject: [ednode path] forKey: @"source"];	
       [opinfo setObject: newpath forKey: @"destination"];	
       [opinfo setObject: [NSArray arrayWithObject: @""] forKey: @"files"];	
-
+      
       [self stopRepNameEditing];
       [[GWorkspace gworkspace] performFileOperation: opinfo];         
     }
-  }
 }
 
 @end
