@@ -1,6 +1,6 @@
 /* GWViewerWindow.m
  *  
- * Copyright (C) 2004-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2013 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: July 2004
@@ -102,11 +102,6 @@
   [[self delegate] goForwardInHistory];
 }
 
-- (void)setViewerBehaviour:(id)sender
-{
-  [[self delegate] setViewerBehaviour: sender];
-}
-
 - (void)setViewerType:(id)sender
 {
   [[self delegate] setViewerType: sender];
