@@ -1,6 +1,6 @@
 /* Finder.m
  *  
- * Copyright (C) 2005-2013 Free Software Foundation, Inc.
+ * Copyright (C) 2005-2016 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: January 2005
@@ -225,7 +225,7 @@ static Finder *finder = nil;
     [addPlaceButt setTitle: NSLocalizedString(@"Add", @"")];
     [removePlaceButt setTitle: NSLocalizedString(@"Remove", @"")];
     [itemsLabel setStringValue: NSLocalizedString(@"Search for items whose:", @"")];
-    [recursiveSwitch setStringValue: NSLocalizedString(@"recursive", @"")];
+    [recursiveSwitch setTitle: NSLocalizedString(@"Recursive", @"")];
     [findButt setTitle: NSLocalizedString(@"Search", @"")];
         
     usesSearchPlaces = [defaults boolForKey: @"uses_search_places"];
@@ -400,7 +400,7 @@ static Finder *finder = nil;
   NSArray *usedModules = [self usedModules];
 
   if ([usedModules count] < [modules count]) {
-    int index = [fmviews indexOfObjectIdenticalTo: aview];  
+    NSUInteger index = [fmviews indexOfObjectIdenticalTo: aview];  
     id module = [self firstUnusedModule];
     id fmview = [[FindModuleView alloc] initWithDelegate: self];
     NSUInteger count;
@@ -712,7 +712,7 @@ static Finder *finder = nil;
   if ([currentSelection count] == 1) {
     title = [[currentSelection objectAtIndex: 0] lastPathComponent];
   } else {
-    title = [NSString stringWithFormat: @"%i %@", [currentSelection count], elmstr];
+    title = [NSString stringWithFormat: @"%lu %@", (unsigned long)[currentSelection count], elmstr];
   }
 
   [[wherePopUp itemAtIndex: SELECTION] setTitle: title];
@@ -887,8 +887,8 @@ static Finder *finder = nil;
     }
   else
     {
-      if ([operation isEqual: @"NSWorkspaceDuplicateOperation"]
-	  || [operation isEqual: @"NSWorkspaceRecycleOperation"])
+      if ([operation isEqual: NSWorkspaceDuplicateOperation]
+	  || [operation isEqual: NSWorkspaceRecycleOperation])
 	{ 
 	  for (i = 0; i < [files count]; i++) {
 	    NSString *fname = [origfiles objectAtIndex: i];
@@ -909,14 +909,14 @@ static Finder *finder = nil;
 	}
     }
 
-  copy = ([operation isEqual: @"NSWorkspaceCopyOperation"]
-                || [operation isEqual: @"NSWorkspaceDuplicateOperation"]); 
+  copy = ([operation isEqual: NSWorkspaceCopyOperation]
+                || [operation isEqual: NSWorkspaceDuplicateOperation]); 
 
-  move = ([operation isEqual: @"NSWorkspaceMoveOperation"] 
+  move = ([operation isEqual: NSWorkspaceMoveOperation] 
                 || [operation isEqual: @"GWorkspaceRenameOperation"]); 
 
-  remove = ([operation isEqual: @"NSWorkspaceDestroyOperation"]
-				        || [operation isEqual: @"NSWorkspaceRecycleOperation"]);
+  remove = ([operation isEqual: NSWorkspaceDestroyOperation]
+				        || [operation isEqual: NSWorkspaceRecycleOperation]);
 
   // Search Places
   if (move || remove) {
