@@ -1,6 +1,6 @@
 /* GWorkspace.h
  *  
- * Copyright (C) 2003-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2003-2016 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: August 2001
@@ -32,9 +32,8 @@
 #define NOEDIT 0
 #define NOXTERM 1
 
-#if !defined(OPEN_MAX) || OPEN_MAX > 255
-#define OPEN_MAX 10
-#endif
+/* defines the maximum number of files to open before issuing a dialog */
+#define MAX_FILES_TO_OPEN_DIALOG 8
 
 
 @class NSWorkspace;
@@ -117,13 +116,13 @@
 {	
   FSNodeRep *fsnodeRep;
   
-	NSArray *selectedPaths;
+  NSArray *selectedPaths;
   NSMutableArray *trashContents;
   NSString *trashPath;
   
   id fswatcher;
   BOOL fswnotifications;
-	NSCountedSet *watchedPaths;
+  NSCountedSet *watchedPaths;
   
   id recyclerApp;
   BOOL recyclerCanQuit;
@@ -135,7 +134,7 @@
   Fiend *fiend;
   
   History *history;
-	int maxHistoryCache;
+  int maxHistoryCache;
     
   GWViewersManager *vwrsManager;
   GWDesktopManager *dtopManager;  
@@ -157,7 +156,7 @@
   
   NSString *gwProcessName;  	      
   NSString *gwBundlePath;  	      
-	NSString *defEditor;
+  NSString *defEditor;
   NSString *defXterm;
   NSString *defXtermArgs;
   BOOL teminalService;
@@ -419,9 +418,9 @@
 
 - (void)performFileOperation:(NSDictionary *)opinfo;
 
-- (BOOL)filenamesWasCutted;
+- (BOOL)filenamesWasCut;
 
-- (void)setFilenamesCutted:(BOOL)value;
+- (void)setFilenamesCut:(BOOL)value;
 
 - (void)lsfolderDragOperation:(NSData *)opinfo
               concludedAtPath:(NSString *)path;
@@ -455,7 +454,7 @@
                       source:(NSString *)source 
                  destination:(NSString *)destination 
                        files:(NSArray *)files 
-                         tag:(int *)tag;
+                         tag:(NSInteger *)tag;
 
 - (BOOL)selectFile:(NSString *)fullPath
 							inFileViewerRootedAtPath:(NSString *)rootFullpath;
