@@ -1,6 +1,6 @@
 /* GWorkspace.m
  *  
- * Copyright (C) 2003-2013 Free Software Foundation, Inc.
+ * Copyright (C) 2003-2016 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  *         Riccardo Mottola
@@ -23,10 +23,14 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
+#include "config.h"
+
 /* the following for getrlimit */
 #include <sys/types.h>
 #include <sys/time.h>
+#ifdef HAVE_SYS_RESOURCE_H
 #include <sys/resource.h>
+#endif
 /* getrlimit */
 
 #import <Foundation/Foundation.h>
@@ -47,7 +51,6 @@
 #import "Dock.h"
 #import "GWViewersManager.h"
 #import "GWViewer.h"
-#import "GWSpatialViewer.h"
 #import "Finder.h"
 #import "Inspector.h"
 #import "Operation.h"
@@ -159,7 +162,7 @@ static GWorkspace *gworkspace = nil;
   NSMenu *menu;
   NSMenu *subMenu;
   NSMenu *windows, *services;  
-  NSMenuItem *menuItem;
+  id<NSMenuItem> menuItem;
     	
   // Info
   menuItem = [mainMenu addItemWithTitle:_(@"Info") action:NULL keyEquivalent:@""];
@@ -196,19 +199,23 @@ static GWorkspace *gworkspace = nil;
   // View
   menuItem = [mainMenu addItemWithTitle:_(@"View") action:NULL keyEquivalent:@""];
   menu = AUTORELEASE ([NSMenu new]);
-  [mainMenu setSubmenu: menu forItem: menuItem];	
-  [menu addItemWithTitle:_(@"Browser") action:@selector(setViewerType:) keyEquivalent:@"b"];
-  [menu addItemWithTitle:_(@"Icon") action:@selector(setViewerType:) keyEquivalent:@"i"];
-  [menu addItemWithTitle:_(@"List") action:@selector(setViewerType:) keyEquivalent:@"l"];
-  menuItem = [menu addItemWithTitle:_(@"Viewer behaviour") action:NULL keyEquivalent:@""];
-  subMenu = AUTORELEASE ([NSMenu new]);
-  [menu setSubmenu: subMenu forItem: menuItem];
-  [subMenu addItemWithTitle:_(@"Browsing") action:@selector(setViewerBehaviour:) keyEquivalent:@"B"];
-  [subMenu addItemWithTitle:_(@"Spatial") action:@selector(setViewerBehaviour:) keyEquivalent:@"S"];
+  [mainMenu setSubmenu: menu forItem: menuItem];
+  menuItem = [[NSMenuItem alloc] initWithTitle:_(@"Browser") action:@selector(setViewerType:) keyEquivalent:@"b"];
+  [menuItem setTag:GWViewTypeBrowser];
+  [menuItem autorelease];
+  [menu addItem:menuItem];
+  menuItem = [[NSMenuItem alloc] initWithTitle:_(@"Icon") action:@selector(setViewerType:) keyEquivalent:@"i"];
+  [menuItem setTag:GWViewTypeIcon];
+  [menuItem autorelease];
+  [menu addItem:menuItem];
+  menuItem = [[NSMenuItem alloc] initWithTitle:_(@"List") action:@selector(setViewerType:) keyEquivalent:@"l"];
+  [menuItem setTag:GWViewTypeList];
+  [menuItem autorelease];
+  [menu addItem:menuItem];
 	
   menuItem = [menu addItemWithTitle:_(@"Show") action:NULL keyEquivalent:@""];
   subMenu = AUTORELEASE ([NSMenu new]);
-  [menu setSubmenu: subMenu forItem: menuItem];	
+  [menu setSubmenu: subMenu forItem: menuItem];
   [subMenu addItemWithTitle:_(@"Name only") action:@selector(setShownType:) keyEquivalent:@""];
   [subMenu addItemWithTitle:_(@"Type") action:@selector(setShownType:) keyEquivalent:@""];
   [subMenu addItemWithTitle:_(@"Size") action:@selector(setShownType:) keyEquivalent:@""];
@@ -223,15 +230,21 @@ static GWorkspace *gworkspace = nil;
   [subMenu addItemWithTitle:_(@"32") action:@selector(setIconsSize:) keyEquivalent:@""];
   [subMenu addItemWithTitle:_(@"36") action:@selector(setIconsSize:) keyEquivalent:@""];
   [subMenu addItemWithTitle:_(@"40") action:@selector(setIconsSize:) keyEquivalent:@""];
-  [subMenu addItemWithTitle:_(@"44") action:@selector(setIconsSize:) keyEquivalent:@""];
   [subMenu addItemWithTitle:_(@"48") action:@selector(setIconsSize:) keyEquivalent:@""];
+  [subMenu addItemWithTitle:_(@"64") action:@selector(setIconsSize:) keyEquivalent:@""];
       
   menuItem = [menu  addItemWithTitle:_(@"Icon Position") action:NULL keyEquivalent:@""];
   subMenu = AUTORELEASE ([NSMenu new]);
   [menu setSubmenu: subMenu forItem: menuItem];	
   [subMenu addItemWithTitle:_(@"Up") action:@selector(setIconsPosition:) keyEquivalent:@""];
   [subMenu addItemWithTitle:_(@"Left") action:@selector(setIconsPosition:) keyEquivalent:@""];
-      
+
+  menuItem = [menu addItemWithTitle:_(@"Thumbnails") action:NULL keyEquivalent:@""];
+  subMenu = AUTORELEASE ([NSMenu new]);
+  [menu setSubmenu: subMenu forItem: menuItem];	
+  [subMenu addItemWithTitle:_(@"Make thumbnail(s)") action:@selector(makeThumbnails:) keyEquivalent:@""];
+  [subMenu addItemWithTitle:_(@"Remove thumbnail(s)") action:@selector(removeThumbnails:) keyEquivalent:@""];
+
   menuItem = [menu addItemWithTitle:_(@"Label Size") action:NULL keyEquivalent:@""];
   subMenu = AUTORELEASE ([NSMenu new]);
   [menu setSubmenu: subMenu forItem: menuItem];
@@ -336,7 +349,7 @@ static GWorkspace *gworkspace = nil;
   
   [self createMenu];
     
-  [isa registerForServices];
+  [[self class] registerForServices];
   
   ASSIGN (gwProcessName, [[NSProcessInfo processInfo] processName]);
   ASSIGN (gwBundlePath, [[NSBundle mainBundle] bundlePath]);
@@ -358,8 +371,6 @@ static GWorkspace *gworkspace = nil;
 	    
   defaults = [NSUserDefaults standardUserDefaults];
   [defaults setObject: gwProcessName forKey: @"GSWorkspaceApplication"];
-
-  [fsnodeRep setVolumes: [ws removableMediaPaths]];
         
   entry = [defaults objectForKey: @"reserved_names"];
   if (entry) 
@@ -745,76 +756,39 @@ static GWorkspace *gworkspace = nil;
   NSArray *selection = [NSArray arrayWithArray: paths];
   id viewer = [vwrsManager rootViewer];
   id nodeView = nil;
-  BOOL newviewer = NO;
 
-  if ([paths count] == 1) {
-    FSNode *node = [FSNode nodeWithPath: [paths objectAtIndex: 0]];
-  
-    if ([node isDirectory] && ([node isPackage] == NO)) {
-      parentnode = [FSNode nodeWithPath: [node path]];
-      selection = [NSArray arrayWithObject: [node path]];
-    }
-  }
-    
-  if (viewer == nil) {
-    NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
-    NSString *path = path_separator();
-    NSString *prefsname = [NSString stringWithFormat: @"viewer_at_%@", path];
-    NSDictionary *viewerPrefs = [defaults objectForKey: prefsname];
-    int type = BROWSING;
-    
-    if (viewerPrefs) {
-      id entry = [viewerPrefs objectForKey: @"spatial"];
-   
-      if (entry) {
-        type = ([entry boolValue] ? SPATIAL : BROWSING);
-      }
-    }
-  
-    if (type == BROWSING) {
-      viewer = [vwrsManager showRootViewer];
-    } else {
-      newviewer = YES;
-    }
-    
-  } else if ([viewer vtype] == SPATIAL) {
-    newviewer = YES;
-  } 
-  
-  if (newviewer)
+  if ([paths count] == 1)
     {
-      viewer = [vwrsManager viewerOfType: SPATIAL
-                                showType: nil
-                                 forNode: parentnode
-                           showSelection: NO
-                          closeOldViewer: NO
-                                forceNew: NO];
+      FSNode *node = [FSNode nodeWithPath: [paths objectAtIndex: 0]];
+      
+      if ([node isDirectory] && ([node isPackage] == NO))
+        {
+          parentnode = [FSNode nodeWithPath: [node path]];
+          selection = [NSArray arrayWithObject: [node path]];
+        }
     }
   
+  if (viewer == nil)
+    viewer = [vwrsManager showRootViewer];
+  
+  
   nodeView = [viewer nodeView];
-  
-  if ([viewer vtype] == BROWSING) {
-    [nodeView showContentsOfNode: parentnode];
-  }
-  
+  [nodeView showContentsOfNode: parentnode];
   [nodeView selectRepsOfPaths: selection];
   
-  if ([nodeView respondsToSelector: @selector(scrollSelectionToVisible)]) {
+  if ([nodeView respondsToSelector: @selector(scrollSelectionToVisible)])
     [nodeView scrollSelectionToVisible];
-  }
 }
 
 - (void)newViewerAtPath:(NSString *)path
 {
   FSNode *node = [FSNode nodeWithPath: path];
-  unsigned type = [vwrsManager typeOfViewerForNode: node];
 
-  [vwrsManager viewerOfType: type 
-                   showType: nil
-                    forNode: node 
-              showSelection: NO
-             closeOldViewer: nil
-                   forceNew: NO];
+  [vwrsManager viewerForNode: node 
+                    showType: 0
+               showSelection: NO
+                    forceNew: NO
+	             withKey: nil];
 }
 
 - (NSImage *)tshelfBackground
@@ -993,9 +967,17 @@ static GWorkspace *gworkspace = nil;
       
       if ([fm fileExistsAtPath: helpPath])
 	{
-	  NSAttributedString *help = [[NSAttributedString alloc] initWithPath: helpPath
-								 documentAttributes: NULL];
-      return AUTORELEASE (help);
+	  NS_DURING
+	    {
+	      NSAttributedString *help = [[NSAttributedString alloc] initWithPath: helpPath
+							       documentAttributes: NULL];
+	      return AUTORELEASE (help);
+	    }
+	  NS_HANDLER
+	    {
+	      return nil;
+	    }
+	  NS_ENDHANDLER;
 	}
     }
   
@@ -1102,10 +1084,6 @@ static GWorkspace *gworkspace = nil;
   
   } else if (sel_isEqual(action, @selector(emptyRecycler:))) {
     return ([trashContents count] != 0);
-  
-  } else if (sel_isEqual(action, @selector(checkRemovableMedia:))) {  
-    return [dtopManager isActive];
-  
   } else if (sel_isEqual(action, @selector(removeTShelfTab:))
               || sel_isEqual(action, @selector(renameTShelfTab:))
                       || sel_isEqual(action, @selector(addTShelfTab:))) {
@@ -1143,7 +1121,7 @@ static GWorkspace *gworkspace = nil;
     }
   }
   
-	return YES;
+  return YES;
 }
            
 - (void)fileSystemWillChange:(NSNotification *)notif
@@ -1231,17 +1209,17 @@ static GWorkspace *gworkspace = nil;
 
 - (void)openSelectedPaths:(NSArray *)paths newViewer:(BOOL)newv
 {
-  int count = [paths count];
-  int i;
+  NSUInteger count = [paths count];
+  NSUInteger i;
   
   [self setSelectedPaths: paths];      
 
-  if (count > OPEN_MAX) {
+  if (count > MAX_FILES_TO_OPEN_DIALOG) {
     NSString *msg1 = NSLocalizedString(@"Are you sure you want to open", @"");
     NSString *msg2 = NSLocalizedString(@"items?", @"");
   
     if (NSRunAlertPanel(nil,
-                [NSString stringWithFormat: @"%@ %i %@", msg1, count, msg2],
+                        [NSString stringWithFormat: @"%@ %lu %@", msg1, (unsigned long)count, msg2],
                 NSLocalizedString(@"Cancel", @""),
                 NSLocalizedString(@"Yes", @""),
                 nil)) {
@@ -1257,21 +1235,24 @@ static GWorkspace *gworkspace = nil;
 
       NS_DURING
         {
-      [ws getInfoForFile: apath application: &defApp type: &type];     
+	  [ws getInfoForFile: apath application: &defApp type: &type];     
 
-      if (type != nil) {
-        if ((type == NSDirectoryFileType) || (type == NSFilesystemFileType)) {
-          if (newv) {    
-            [self newViewerAtPath: apath];    
-          }
-        } else if ((type == NSPlainFileType) 
-                            || ([type isEqual: NSShellCommandFileType])) {
-          [self openFile: apath];
-
-        } else if (type == NSApplicationFileType) {
-          [ws launchApplication: apath];
-        }
-      }
+	  if (type != nil)
+	    {
+	      if ((type == NSDirectoryFileType) || (type == NSFilesystemFileType))
+		{
+		  if (newv)
+		    [self newViewerAtPath: apath];    
+		}
+	      else if ((type == NSPlainFileType) || ([type isEqual: NSShellCommandFileType]))
+		{
+		  [self openFile: apath];
+		}
+	      else if (type == NSApplicationFileType)
+		{
+		  [ws launchApplication: apath];
+		}
+	    }
         }
       NS_HANDLER
         {
@@ -1290,7 +1271,7 @@ static GWorkspace *gworkspace = nil;
 - (void)openSelectedPathsWith
 {
   BOOL canopen = YES;
-  int i;
+  NSUInteger i;
 
   for (i = 0; i < [selectedPaths count]; i++) {
     FSNode *node = [FSNode nodeWithPath: [selectedPaths objectAtIndex: i]];
@@ -1332,7 +1313,7 @@ static GWorkspace *gworkspace = nil;
 	  urlString = [weblocDict objectForKey:@"URL"];
 	  aURL = [NSURL URLWithString: urlString];
         }
-    }	
+    }
   
   NS_DURING
     {
@@ -1401,10 +1382,10 @@ static GWorkspace *gworkspace = nil;
             isDirectory:(BOOL)directory
 {
   NSString *fullPath;
-	NSString *fileName;
-	NSString *operation;
+  NSString *fileName;
+  NSString *operation;
   NSMutableDictionary *notifObj;  
-  int suff;
+  unsigned suff;
     
 	if ([self verifyFileAtPath: basePath] == NO) {
 		return;
@@ -1441,8 +1422,8 @@ static GWorkspace *gworkspace = nil;
     }     
   }
 
-	notifObj = [NSMutableDictionary dictionaryWithCapacity: 1];		
-	[notifObj setObject: operation forKey: @"operation"];	
+  notifObj = [NSMutableDictionary dictionaryWithCapacity: 1];		
+  [notifObj setObject: operation forKey: @"operation"];	
   [notifObj setObject: basePath forKey: @"source"];	
   [notifObj setObject: basePath forKey: @"destination"];	
   [notifObj setObject: [NSArray arrayWithObject: fileName] forKey: @"files"];	
@@ -1454,7 +1435,8 @@ static GWorkspace *gworkspace = nil;
 {
   NSString *basePath;
   NSMutableArray *files;
-  int tag, i;
+  NSInteger tag;
+  NSUInteger i;
 
   basePath = [NSString stringWithString: [selectedPaths objectAtIndex: 0]];
   basePath = [basePath stringByDeletingLastPathComponent];
@@ -1480,7 +1462,8 @@ static GWorkspace *gworkspace = nil;
 {
   NSString *basePath;
   NSMutableArray *files;
-  int tag, i;
+  NSInteger tag;
+  NSUInteger i;
 
   basePath = [NSString stringWithString: [selectedPaths objectAtIndex: 0]];
   basePath = [basePath stringByDeletingLastPathComponent];
@@ -1507,7 +1490,8 @@ static GWorkspace *gworkspace = nil;
   NSArray *vpaths = [ws mountedLocalVolumePaths];
   NSMutableArray *umountPaths = [NSMutableArray array];
   NSMutableArray *files = [NSMutableArray array];
-  int tag, i;
+  NSUInteger i;
+  NSInteger tag;
 
   for (i = 0; i < [selectedPaths count]; i++) {
     NSString *path = [selectedPaths objectAtIndex: i];
@@ -1523,23 +1507,25 @@ static GWorkspace *gworkspace = nil;
     [ws unmountAndEjectDeviceAtPath: [umountPaths objectAtIndex: i]];
   }
 
-  if ([files count]) {
-    NSString *basePath = [NSString stringWithString: [selectedPaths objectAtIndex: 0]];
+  if ([files count])
+    {
+      NSString *basePath = [NSString stringWithString: [selectedPaths objectAtIndex: 0]];
 
-    basePath = [basePath stringByDeletingLastPathComponent];
+      basePath = [basePath stringByDeletingLastPathComponent];
 
-	  if ([fm isWritableFileAtPath: basePath] == NO) {
-		  NSString *err = NSLocalizedString(@"Error", @"");
-		  NSString *msg = NSLocalizedString(@"You do not have write permission\nfor", @"");
-		  NSString *buttstr = NSLocalizedString(@"Continue", @"");
-      NSRunAlertPanel(err, [NSString stringWithFormat: @"%@ \"%@\"!\n", msg, basePath], buttstr, nil, nil);   
-		  return;
-	  }
+      if ([fm isWritableFileAtPath: basePath] == NO)
+        {
+          NSString *err = NSLocalizedString(@"Error", @"");
+          NSString *msg = NSLocalizedString(@"You do not have write permission\nfor", @"");
+          NSString *buttstr = NSLocalizedString(@"Continue", @"");
+          NSRunAlertPanel(err, [NSString stringWithFormat: @"%@ \"%@\"!\n", msg, basePath], buttstr, nil, nil);   
+          return;
+        }
 
-    [self performFileOperation: @"NSWorkspaceRecycleOperation"
-                    source: basePath destination: trashPath 
-                                              files: files tag: &tag];
-  }
+      [self performFileOperation: NSWorkspaceRecycleOperation
+                          source: basePath destination: trashPath 
+                           files: files tag: &tag];
+    }
 }
 
 - (BOOL)verifyFileAtPath:(NSString *)path
@@ -1593,18 +1579,19 @@ static GWorkspace *gworkspace = nil;
   NSArray *deleted = [info objectForKey: @"deleted"];	
   NSArray *created = [info objectForKey: @"created"];	
   NSMutableArray *tmbdirs = [NSMutableArray array];
-  int i;
+  NSUInteger i;
 
   [fsnodeRep thumbnailsDidChange: info];
 
-  if ([fsnodeRep usesThumbnails] == NO) {
+  if ([fsnodeRep usesThumbnails] == NO)
     return;
-  } else {
-    NSString *thumbnailDir = [NSSearchPathForDirectoriesInDomains(NSLibraryDirectory, NSUserDomainMask, YES) lastObject];
 
-    thumbnailDir = [thumbnailDir stringByAppendingPathComponent: @"Thumbnails"];
+  NSString *thumbnailDir = [NSSearchPathForDirectoriesInDomains(NSLibraryDirectory, NSUserDomainMask, YES) lastObject];
+
+  thumbnailDir = [thumbnailDir stringByAppendingPathComponent: @"Thumbnails"];
   
-    if ([deleted count]) {
+  if (deleted && [deleted count])
+    {
       for (i = 0; i < [deleted count]; i++) {
         NSString *path = [deleted objectAtIndex: i];
         NSString *dir = [path stringByDeletingLastPathComponent];
@@ -1617,14 +1604,13 @@ static GWorkspace *gworkspace = nil;
       [vwrsManager thumbnailsDidChangeInPaths: tmbdirs];
       [dtopManager thumbnailsDidChangeInPaths: tmbdirs];
 
-      if ([tshelfWin isVisible]) {
+      if ([tshelfWin isVisible])
         [tshelfWin updateIcons]; 
-		  }
 
       [tmbdirs removeAllObjects];
     }
 
-    if ([created count]) {
+    if (created && [created count]) {
       NSString *dictName = @"thumbnails.plist";
       NSString *dictPath = [thumbnailDir stringByAppendingPathComponent: dictName];
       
@@ -1652,12 +1638,15 @@ static GWorkspace *gworkspace = nil;
         [tshelfWin updateIcons]; 
 		  }
     }
-  }
 }
 
 - (void)removableMediaPathsDidChange:(NSNotification *)notif
 {
-  [fsnodeRep setVolumes: [ws removableMediaPaths]];
+  NSArray *removables;
+
+  removables = [[[NSUserDefaults standardUserDefaults] persistentDomainForName: NSGlobalDomain] objectForKey: @"GSRemovableMediaPaths"];
+
+  [fsnodeRep setVolumes: removables];
   [dtopManager removableMediaPathsDidChange];
 }
 
@@ -1721,7 +1710,7 @@ static GWorkspace *gworkspace = nil;
   NSDictionary *changedInfo = [notif userInfo];
   NSString *app = [changedInfo objectForKey: @"app"];
   NSArray *extensions = [changedInfo objectForKey: @"exts"];
-  int i;
+  NSUInteger i;
 
   for (i = 0; i < [extensions count]; i++) {
     [[NSWorkspace sharedWorkspace] setBestApp: app
@@ -1751,7 +1740,7 @@ static GWorkspace *gworkspace = nil;
     {
       NSString *cmd;
       NSMutableArray *arguments;
-      int i;
+      unsigned i;
     
       cmd = [NSTask launchPathForTool: @"fswatcher"];    
                 
@@ -1774,7 +1763,7 @@ static GWorkspace *gworkspace = nil;
                                                                       host: @""];                  
         if (fswatcher)
 	{
-          [startAppWin updateProgressBy: 40.0 - i];
+          [startAppWin updateProgressBy: 40.0 - (double)i];
           break;
         }
       }
@@ -1883,7 +1872,7 @@ static GWorkspace *gworkspace = nil;
       
       if (recyclerApp == nil)
         {
-          int i;
+          unsigned i;
           
           [startAppWin showWindowWithTitle: @"GWorkspace"
                                    appName: @"Recycler"
@@ -1901,7 +1890,7 @@ static GWorkspace *gworkspace = nil;
                                                                               host: @""];                  
               if (recyclerApp)
                 {
-                  [startAppWin updateProgressBy: 80.0 - i];
+                  [startAppWin updateProgressBy: 80.0 - (double)i];
                   break;
                 }
             }
@@ -1978,7 +1967,7 @@ static GWorkspace *gworkspace = nil;
 	{
 	  NSString *cmd;
 	  NSMutableArray *arguments;
-	  int i;
+	  unsigned i;
     
 	  cmd = [NSTask launchPathForTool: @"ddbd"];    
                 
@@ -2003,7 +1992,7 @@ static GWorkspace *gworkspace = nil;
 								       host: @""];                  
 	      if (ddbd)
 		{
-		  [startAppWin updateProgressBy: 40.0 - i];
+		  [startAppWin updateProgressBy: 40.0 - (double)i];
 		  break;
 		}
 	    }
@@ -2096,7 +2085,7 @@ static GWorkspace *gworkspace = nil;
 
     if (mdextractor == nil) {
 	    NSString *cmd;
-      int i;
+      unsigned i;
     
       cmd = [NSTask launchPathForTool: @"mdextractor"];    
                 
@@ -2115,7 +2104,7 @@ static GWorkspace *gworkspace = nil;
         mdextractor = [NSConnection rootProxyForConnectionWithRegisteredName: @"mdextractor" 
                                                                         host: @""];                  
         if (mdextractor) {
-          [startAppWin updateProgressBy: 80.0 - i];
+          [startAppWin updateProgressBy: 80.0 - (double)i];
           break;
         }
       }
@@ -2298,11 +2287,20 @@ static GWorkspace *gworkspace = nil;
   NSMenu *menu = [[[NSApp mainMenu] itemWithTitle: NSLocalizedString(@"Tools", @"")] submenu];
   id item;
 
-  if ([dtopManager isActive] == NO) {
-    [dtopManager activateDesktop];
-    item = [menu itemWithTitle: NSLocalizedString(@"Show Desktop", @"")];
-    [item setTitle: NSLocalizedString(@"Hide Desktop", @"")];
-  } else {
+  if ([dtopManager isActive] == NO)
+    {
+      [dtopManager activateDesktop];
+      item = [menu itemWithTitle: NSLocalizedString(@"Show Desktop", @"")];
+      [item setTitle: NSLocalizedString(@"Hide Desktop", @"")];
+      if (recyclerApp)
+	{
+	  recyclerCanQuit = YES;
+	  [recyclerApp terminateApplication];
+	  item = [menu itemWithTitle: NSLocalizedString(@"Hide Recycler", @"")];
+	  [item setTitle: NSLocalizedString(@"Show Recycler", @"")];
+	}
+    }
+  else {
     [dtopManager deactivateDesktop];
     item = [menu itemWithTitle: NSLocalizedString(@"Hide Desktop", @"")];
     [item setTitle: NSLocalizedString(@"Show Desktop", @"")];
@@ -2477,7 +2475,7 @@ static GWorkspace *gworkspace = nil;
                    owner: nil];
 
         if ([pb setPropertyList: selection forType: NSFilenamesPboardType]) {
-          [fileOpsManager setFilenamesCutted: YES];
+          [fileOpsManager setFilenamesCut: YES];
         }
       }
     } 
@@ -2519,7 +2517,7 @@ static GWorkspace *gworkspace = nil;
                    owner: nil];
 
         if ([pb setPropertyList: selection forType: NSFilenamesPboardType]) {
-          [fileOpsManager setFilenamesCutted: NO];
+          [fileOpsManager setFilenamesCut: NO];
         }
       }
     }
@@ -2547,7 +2545,7 @@ static GWorkspace *gworkspace = nil;
         NSArray *sourcePaths = [pb propertyListForType: NSFilenamesPboardType];   
 
         if (sourcePaths) {
-          BOOL cutted = [fileOpsManager filenamesWasCutted];
+          BOOL cut = [fileOpsManager filenamesWasCut];
           id nodeView;
 
           if ([vwrsManager hasViewerWithWindow: kwin]) {
@@ -2557,7 +2555,7 @@ static GWorkspace *gworkspace = nil;
           }
 
           if ([nodeView validatePasteOfFilenames: sourcePaths
-                                       wasCutted: cutted]) {
+                                       wasCut: cut]) {
             NSMutableDictionary *opDict = [NSMutableDictionary dictionary];
             NSString *source = [[sourcePaths objectAtIndex: 0] stringByDeletingLastPathComponent];
             NSString *destination = [[nodeView shownNode] path];
@@ -2570,7 +2568,7 @@ static GWorkspace *gworkspace = nil;
               [files addObject: [spath lastPathComponent]];
             }  
 
-            if (cutted) {
+            if (cut) {
               if ([source isEqual: trashPath]) {
                 operation = @"GWorkspaceRecycleOutOperation";
               } else {
@@ -2600,9 +2598,7 @@ static GWorkspace *gworkspace = nil;
 
 - (void)checkRemovableMedia:(id)sender
 {
-  if ([dtopManager isActive]) {
-    [dtopManager checkNewRemovableMedia];
-  }	
+  [dtopManager checkNewRemovableMedia];	
 }
 
 - (void)emptyRecycler:(id)sender
@@ -2611,7 +2607,7 @@ static GWorkspace *gworkspace = nil;
   FSNode *node = [FSNode nodeWithPath: trashPath];
   NSMutableArray *subNodes = [[node subNodes] mutableCopy];
   int count = [subNodes count];
-  int i;  
+  NSUInteger i;  
   
   for (i = 0; i < count; i++) {
     FSNode *nd = [subNodes objectAtIndex: i];
@@ -2628,7 +2624,7 @@ static GWorkspace *gworkspace = nil;
     NSMutableDictionary *opinfo = [NSMutableDictionary dictionary];
 
     for (i = 0; i < [subNodes count]; i++) {
-      [files addObject: [(FSNode *)[subNodes objectAtIndex: i] name]];
+      [files addObject: [[(FSNode *)[subNodes objectAtIndex: i] path] lastPathComponent]];
     }
 
     [opinfo setObject: @"GWorkspaceEmptyRecyclerOperation" forKey: @"operation"];
@@ -2664,17 +2660,17 @@ static GWorkspace *gworkspace = nil;
 - (void)openSelectionWithApp:(id)sender
 {
   NSString *appName = (NSString *)[(NSMenuItem *)sender representedObject];
-  int count = (selectedPaths ? [selectedPaths count] : 0);
+  NSUInteger count = (selectedPaths ? [selectedPaths count] : 0);
   
   if (count) {
-    int i;
+    NSUInteger i;
 
-    if (count > OPEN_MAX) {
+    if (count > MAX_FILES_TO_OPEN_DIALOG) {
       NSString *msg1 = NSLocalizedString(@"Are you sure you want to open", @"");
       NSString *msg2 = NSLocalizedString(@"items?", @"");
 
       if (NSRunAlertPanel(nil,
-                  [NSString stringWithFormat: @"%@ %i %@", msg1, count, msg2],
+                          [NSString stringWithFormat: @"%@ %lu %@", msg1, (unsigned long)count, msg2],
                   NSLocalizedString(@"Cancel", @""),
                   NSLocalizedString(@"Yes", @""),
                   nil)) {
@@ -2709,23 +2705,23 @@ static GWorkspace *gworkspace = nil;
   NSString *source = [opinfo objectForKey: @"source"];
   NSString *destination = [opinfo objectForKey: @"destination"];
   NSArray *files = [opinfo objectForKey: @"files"];
-  int tag;
+  NSInteger tag;
 
-  if (destination == nil && [operation isEqualToString:@"NSWorkspaceRecycleOperation"])
+  if (destination == nil && [operation isEqualToString:NSWorkspaceRecycleOperation])
     destination = [self trashPath];
 
   [self performFileOperation: operation source: source 
 		 destination: destination files: files tag: &tag];
 }
 
-- (BOOL)filenamesWasCutted
+- (BOOL)filenamesWasCut
 {
-  return [fileOpsManager filenamesWasCutted];
+  return [fileOpsManager filenamesWasCut];
 }
 
-- (void)setFilenamesCutted:(BOOL)value
+- (void)setFilenamesCut:(BOOL)value
 {
-  [fileOpsManager setFilenamesCutted: value];
+  [fileOpsManager setFilenamesCut: value];
 }
 
 - (void)lsfolderDragOperation:(NSData *)opinfo
