@@ -1,8 +1,9 @@
 /* DesktopPref.m
  *  
- * Copyright (C) 2005-2012 Free Software Foundation, Inc.
+ * Copyright (C) 2005-2016 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
+ *         Riccardo Mottola <rm@gnu.org>
  * Date: January 2005
  *
  * This file is part of the GNUstep GWorkspace application
@@ -60,7 +61,6 @@ static NSString *nibName = @"DesktopPref";
       DockPosition dockpos;
       DockStyle dockstyle;
       id cell;
-      NSRect r;
 
       RETAIN (prefbox);
       RELEASE (win);
@@ -120,6 +120,7 @@ static NSString *nibName = @"DesktopPref";
       [[tabView tabViewItemAtIndex: 0] setLabel: NSLocalizedString(@"Background", @"")];
       [[tabView tabViewItemAtIndex: 1] setLabel: NSLocalizedString(@"General", @"")];
 
+      [colorLabel setStringValue:_(@"Color:")];
       cell = [imagePosMatrix cellAtRow: BackImageCenterStyle column: 0];
       [cell setTitle: NSLocalizedString(@"center", @"")];
       cell = [imagePosMatrix cellAtRow: BackImageFitStyle column: 0];
@@ -131,17 +132,20 @@ static NSString *nibName = @"DesktopPref";
       [useImageSwitch setTitle: NSLocalizedString(@"Use image", @"")];  
       [chooseImageButt setTitle: NSLocalizedString(@"Choose", @"")]; 
 
+      [dockBox setTitle: _(@"Dock")];
       [useDockCheck setTitle: NSLocalizedString(@"Show Dock", @"")];
-      [dockPosLabel setStringValue: NSLocalizedString(@"Dock position:", @"")];
+      [dockPosLabel setStringValue: NSLocalizedString(@"Position:", @"")];
       cell = [dockPosMatrix cellAtRow: 0 column: 0];
       [cell setTitle: NSLocalizedString(@"Left", @"")];
-      cell = [dockPosMatrix cellAtRow: 0 column: 1];
+      cell = [dockPosMatrix cellAtRow: 1 column: 0];
       [cell setTitle: NSLocalizedString(@"Right", @"")];
-      [dockStyleLabel setStringValue: NSLocalizedString(@"Dock style:", @"")];
+      [dockStyleLabel setStringValue: NSLocalizedString(@"Style:", @"")];
       cell = [dockStyleMatrix cellAtRow: 0 column: 0];
       [cell setTitle: NSLocalizedString(@"Classic", @"")];
-      cell = [dockStyleMatrix cellAtRow: 0 column: 1];
+      cell = [dockStyleMatrix cellAtRow: 1 column: 0];
       [cell setTitle: NSLocalizedString(@"Modern", @"")];
+
+      [omnipresentCheck setTitle: _(@"Omnipresent")];
       [hideTShelfCheck setTitle: NSLocalizedString(@"Autohide Tabbed Shelf", @"")];
     }
   }
@@ -172,7 +176,7 @@ static NSString *nibName = @"DesktopPref";
 - (IBAction)chooseImage:(id)sender
 {
   NSOpenPanel *openPanel;
-  int result;
+  NSInteger result;
    
   openPanel = [NSOpenPanel openPanel];
   [openPanel setTitle: NSLocalizedString(@"Choose Image", @"")];	
@@ -188,7 +192,7 @@ static NSString *nibName = @"DesktopPref";
                                       file: nil 
                                      types: [NSImage imageFileTypes]];
                                      
-	if (result == NSOKButton) {
+  if (result == NSOKButton) {
     CREATE_AUTORELEASE_POOL (pool);
     NSString *impath = [openPanel filename];
     NSImage *image = [[NSImage alloc] initWithContentsOfFile: impath];
@@ -219,7 +223,7 @@ static NSString *nibName = @"DesktopPref";
 - (IBAction)setImageStyle:(id)sender
 {
   id cell = [imagePosMatrix selectedCell];
-  int row, col;
+  NSInteger row, col;
   
   [imagePosMatrix getRow: &row column: &col ofCell: cell];
   [[manager desktopView] setBackImageStyle: row];  
@@ -254,7 +258,7 @@ static NSString *nibName = @"DesktopPref";
 - (IBAction)setDockPosition:(id)sender
 {
   id cell = [dockPosMatrix selectedCell];
-  int row, col;
+  NSInteger row, col;
   
   [dockPosMatrix getRow: &row column: &col ofCell: cell];
   [manager setDockPosition: (row == 0) ? DockPositionLeft : DockPositionRight];
@@ -263,7 +267,7 @@ static NSString *nibName = @"DesktopPref";
 - (IBAction)setDockStyle:(id)sender
 {
   id cell = [dockStyleMatrix selectedCell];
-  int row, col;
+  NSInteger row, col;
   
   [dockStyleMatrix getRow: &row column: &col ofCell: cell];
   [[manager dock] setStyle: (row == 0) ? DockStyleClassic : DockStyleModern];
