@@ -1,6 +1,6 @@
 /* PrefController.m
  *  
- * Copyright (C) 2003 Free Software Foundation, Inc.
+ * Copyright (C) 2003-2010 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: August 2001
@@ -19,23 +19,25 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
-#include <Foundation/Foundation.h>
-#include <AppKit/AppKit.h>
-#include "PrefController.h"
-#include "DefEditorPref.h"
-#include "XTermPref.h"
-#include "DefSortOrderPref.h"
-#include "IconsPref.h"
-#include "HiddenFilesPref.h"
-#include "HistoryPref.h"
-#include "BrowserViewerPref.h"
-#include "DesktopPref.h"
-#include "VolumesPref.h"
-#include "GWorkspace.h"
-#include "GNUstep.h"
+#import <Foundation/Foundation.h>
+#import <AppKit/AppKit.h>
+#import <GNUstepBase/GNUstep.h>
+
+#import "PrefController.h"
+#import "DefEditorPref.h"
+#import "XTermPref.h"
+#import "DefSortOrderPref.h"
+#import "IconsPref.h"
+#import "HiddenFilesPref.h"
+#import "HistoryPref.h"
+#import "BrowserViewerPref.h"
+#import "DesktopPref.h"
+#import "OperationPrefs.h"
+#import "GWorkspace.h"
+
 
 static NSString *nibName = @"PrefWindow";
 
@@ -87,7 +89,7 @@ RELEASE (currentPref)
   ADD_PREF_VIEW ([IconsPref class]);
   ADD_PREF_VIEW ([HiddenFilesPref class]);
   ADD_PREF_VIEW ([DesktopPref class]);
-  ADD_PREF_VIEW ([VolumesPref class]);
+  ADD_PREF_VIEW ([OperationPrefs class]);
   ADD_PREF_VIEW ([HistoryPref class]);
 
   currentPref = nil;
