@@ -1,6 +1,6 @@
 /* TShelfWin.m
  *  
- * Copyright (C) 2003-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2003-2012 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: August 2001
@@ -57,11 +57,11 @@
     NSDictionary *tshelfDict;
     id entry;
     NSArray *tabsArr;    
-		TShelfViewItem *item;
+    TShelfViewItem *item;
     TShelfIconsView *view;
-    int i;
-    
-		[self setReleasedWhenClosed: NO];
+    NSUInteger i;
+
+    [self setReleasedWhenClosed: NO];
     [self setExcludedFromWindowsMenu: YES];
         
     tView = [[TShelfView alloc] initWithFrame: [[self contentView] bounds]];
@@ -87,23 +87,23 @@
         NSArray *iconsArr = [tabDict objectForKey: @"icons"];
         NSNumber *iconsType = [tabDict objectForKey: @"iconstype"];
         int itype;
-    
+
         if (iconsType) {
           itype = [iconsType intValue];
         } else {
           itype = FILES_TAB;
         }
-    
+
         item = [[TShelfViewItem alloc] initWithTabType: itype];
         [item setLabel: label];
-        
         view = [[TShelfIconsView alloc] initWithIconsDescription: iconsArr
                                                        iconsType: itype
                               lastView: ([label isEqual: @"last"] ? YES : NO)];
+
         [view setFrame: NSMakeRect(0, 0, sizew, 80)];    
         [item setView: view];
         RELEASE (view);
-        
+ 
         if ([label isEqual: @"last"]) {
           [tView setLastTabItem: item];
         } else {
@@ -274,28 +274,29 @@
     return;
   }
 
-	dialog = [[SympleDialog alloc] initWithTitle: NSLocalizedString(@"Add Tab", @"") 
-                                      editText: @""
-                                   switchTitle: NSLocalizedString(@"pasteboard tab", @"")];
-  AUTORELEASE (dialog);
-	[dialog center];
+  dialog = [[SympleDialog alloc] initWithTitle: NSLocalizedString(@"Add Tab", @"") 
+				      editText: @""
+				   switchTitle: NSLocalizedString(@"pasteboard tab", @"")];
+  [dialog center];
   [dialog makeKeyWindow];
   [dialog orderFrontRegardless];
-
+  
   result = [dialog runModal];
-	if (result != NSAlertDefaultReturn) {
+  [dialog release];
+  if (result != NSAlertDefaultReturn) {
     return;
   }  
 
   tabName = [dialog getEditFieldText];
 
-  if ([tabName length] == 0) {
-		NSString *msg = NSLocalizedString(@"No name supplied!", @"");
-		NSString *buttstr = NSLocalizedString(@"Continue", @"");		
-    NSRunAlertPanel(nil, msg, buttstr, nil, nil);  
-    return;
-  }
-
+  if ([tabName length] == 0)
+    {
+      NSString *msg = NSLocalizedString(@"No name supplied!", @"");
+      NSString *buttstr = NSLocalizedString(@"Continue", @"");		
+      NSRunAlertPanel(nil, msg, buttstr, nil, nil);  
+      return;
+    }
+  
   items = [tView items];
 
   duplicate = NO;
@@ -308,12 +309,13 @@
     }
   }
 
-  if (duplicate) {
-		NSString *msg = NSLocalizedString(@"Duplicate tab name!", @"");
-		NSString *buttstr = NSLocalizedString(@"Continue", @"");		
-    NSRunAlertPanel(nil, msg, buttstr, nil, nil);  
-    return;
-  }
+  if (duplicate)
+    {
+      NSString *msg = NSLocalizedString(@"Duplicate tab name!", @"");
+      NSString *buttstr = NSLocalizedString(@"Continue", @"");		
+      NSRunAlertPanel(nil, msg, buttstr, nil, nil);  
+      return;
+    }
   
   itype = ([dialog switchButtState] == NSOnState) ? DATA_TAB : FILES_TAB;
   
@@ -339,8 +341,7 @@
 {
   NSArray *items;
   TShelfViewItem *item;
-	NSString *title, *msg, *buttstr;
-  int index;
+  NSString *title, *msg, *buttstr;
   int result;
     
   if ([self isVisible] == NO) {
@@ -349,7 +350,6 @@
 
   items = [tView items];
   item = [tView selectedTabItem];
-  index = [tView indexOfItem: item];
   
   if (([items count] == 1) || (item == [tView lastTabItem])) {
 		msg = NSLocalizedString(@"You can't remove the last tab!", @"");
@@ -394,45 +394,49 @@
   if ([self isVisible] == NO) {
     return;
   }
-
+  
   items = [tView items];
   item = [tView selectedTabItem];
   oldName = [item label];
   index = [tView indexOfItem: item];
 
-  if (item == [tView lastTabItem]) {
-		NSString *msg = NSLocalizedString(@"You can't rename this tab!", @"");
-		NSString *buttstr = NSLocalizedString(@"Continue", @"");		
-    NSRunAlertPanel(nil, msg, buttstr, nil, nil);  
-    return;
-  }
-
-	dialog = [[SympleDialog alloc] initWithTitle: NSLocalizedString(@"Rename Tab", @"") 
+  if (item == [tView lastTabItem])
+    {
+      NSString *msg = NSLocalizedString(@"You can't rename this tab!", @"");
+      NSString *buttstr = NSLocalizedString(@"Continue", @"");		
+      NSRunAlertPanel(nil, msg, buttstr, nil, nil);  
+      return;
+    }
+  
+  dialog = [[SympleDialog alloc] initWithTitle: NSLocalizedString(@"Rename Tab", @"") 
                                       editText: oldName
                                    switchTitle: nil];
-  AUTORELEASE (dialog);
-	[dialog center];
+  
+  [dialog center];
   [dialog makeKeyWindow];
   [dialog orderFrontRegardless];
-
+  
   result = [dialog runModal];
-	if(result != NSAlertDefaultReturn) {
+  [dialog release];
+
+  if(result != NSAlertDefaultReturn) {
     return;
   }  
 
   tabName = [dialog getEditFieldText];
 
-  if ([tabName length] == 0) {
-		NSString *msg = NSLocalizedString(@"No name supplied!", @"");
-		NSString *buttstr = NSLocalizedString(@"Continue", @"");		
-    NSRunAlertPanel(nil, msg, buttstr, nil, nil);  
-    return;
-  }
-
+  if ([tabName length] == 0)
+    {
+      NSString *msg = NSLocalizedString(@"No name supplied!", @"");
+      NSString *buttstr = NSLocalizedString(@"Continue", @"");		
+      NSRunAlertPanel(nil, msg, buttstr, nil, nil);
+      return;
+    }
+  
   duplicate = NO;
   for (i = 0; i < [items count]; i++) {
     TShelfViewItem *itm = [items objectAtIndex: i];
-
+    
     if ([[itm label] isEqual: tabName]) {
       duplicate = YES;
       break;
