@@ -1,6 +1,6 @@
 /* Annotations.h
  *  
- * Copyright (C) 2005 Free Software Foundation, Inc.
+ * Copyright (C) 2005-2010 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: February 2005
@@ -19,13 +19,11 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
-#ifndef ANNOTATION_H
-#define ANNOTATION_H
 
-#include <Foundation/Foundation.h>
+#import <Foundation/Foundation.h>
 
 @class FSNode;
 @class NSView;
@@ -33,11 +31,11 @@
 @interface Annotations: NSObject
 {
   IBOutlet id win;
-  IBOutlet id mainBox;
-  IBOutlet id topBox;
+  IBOutlet NSBox *mainBox;
+  IBOutlet NSBox *topBox;
   IBOutlet id iconView;
   IBOutlet id titleField;
-  IBOutlet id toolsBox;
+  IBOutlet NSBox *toolsBox;
   IBOutlet id textView;
   IBOutlet id okButt;
 
@@ -59,4 +57,3 @@
 
 @end
 
-#endif // ANNOTATION_H
