@@ -1,6 +1,6 @@
 /* Attributes.m
  *  
- * Copyright (C) 2004-2013 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2016 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: January 2004
@@ -139,8 +139,8 @@ static BOOL sizeStop = NO;
     [oexebutt setAlternateImage: onImage];     
     [oexebutt setTag: SINGLE];       
 
-	  [revertButt setEnabled: NO];
-	  [okButt setEnabled: NO];
+    [revertButt setEnabled: NO];
+    [okButt setEnabled: NO];
   
     /* Internationalization */
     [linkToLabel setStringValue: NSLocalizedString(@"Link to:", @"")];
@@ -153,15 +153,15 @@ static BOOL sizeStop = NO;
     [readLabel setStringValue: NSLocalizedString(@"Read", @"")];
     [writeLabel setStringValue: NSLocalizedString(@"Write", @"")];
     [executeLabel setStringValue: NSLocalizedString(@"Execute", @"")];
-    [uLabel setStringValue: NSLocalizedString(@"Owner", @"")];
+    [uLabel setStringValue: NSLocalizedString(@"Owner_short", @"")];
     [gLabel setStringValue: NSLocalizedString(@"Group", @"")];
-    [oLabel setStringValue: NSLocalizedString(@"Others", @"")];
+    [oLabel setStringValue: NSLocalizedString(@"Other", @"")];
     [insideButt setTitle: NSLocalizedString(@"also apply to files inside selection", @"")];
     [revertButt setTitle: NSLocalizedString(@"Revert", @"")];
     [okButt setTitle: NSLocalizedString(@"OK", @"")];
   } 
 		
-	return self;
+  return self;
 }
 
 - (NSView *)inspView
@@ -210,7 +210,7 @@ static BOOL sizeStop = NO;
       NSImage *icon = [[FSNodeRep sharedInstance] iconOfSize: ICNSIZE forNode: node];
       
       [iconView setImage: icon];
-      [titleField setStringValue: [currentPath lastPathComponent]];
+      [titleField setStringValue: [node name]];
       
       usr = [attributes objectForKey: NSFileOwnerAccountName];
       grp = [attributes objectForKey: NSFileGroupOwnerAccountName];
@@ -286,7 +286,7 @@ static BOOL sizeStop = NO;
       NSImage *icon = [[FSNodeRep sharedInstance] multipleSelectionIconOfSize: ICNSIZE];
       NSString *items = NSLocalizedString(@"items", @"");
       
-      items = [NSString stringWithFormat: @"%i %@", [paths count], items];
+      items = [NSString stringWithFormat: @"%lu %@", (unsigned long)[paths count], items];
       [titleField setStringValue: items];  
       [iconView setImage: icon];
   
