@@ -1,6 +1,6 @@
 /* ImageViewer.h
  *  
- * Copyright (C) 2004 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2016 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: January 2004
@@ -25,9 +25,9 @@
 #ifndef IMAGEVIEWER_H
 #define IMAGEVIEWER_H
 
-#include <Foundation/Foundation.h>
-#include <AppKit/NSView.h>
-#include "ContentViewersProtocol.h"
+#import <Foundation/Foundation.h>
+#import <AppKit/NSView.h>
+#import "ContentViewersProtocol.h"
 
 @class NSImage;
 @class NSImageView;
@@ -35,7 +35,7 @@
 @class NSButton;
 @class NSWorkspace;
 @class ProgressView;
-
+@class ImageResizer;
 @protocol ContentInspectorProtocol
 
 - (void)contentsReadyAt:(NSString *)path;
@@ -69,26 +69,16 @@
   NSString *editPath;
   
   NSConnection *conn;  
-  NSConnection *resizerConn;
-  BOOL waitingResizer;
-  id resizer;
+  ImageResizer *resizer;
   
   id <ContentInspectorProtocol>inspector;
   NSFileManager *fm;
-  NSNotificationCenter *nc;
   NSWorkspace *ws;
 }
 
-- (void)checkResizer:(id)sender;
-
 - (void)setResizer:(id)anObject;
 
-- (BOOL)connection:(NSConnection *)ancestor 
-								shouldMakeNewConnection:(NSConnection *)newConn;
-
-- (void)connectionDidDie:(NSNotification *)notification;
-
-- (void)imageReady:(NSData *)data;
+- (void)imageReady:(NSDictionary *)imginfo;
 
 - (void)editFile:(id)sender;
 
@@ -100,14 +90,14 @@
 @interface ProgressView : NSView 
 {
   NSMutableArray *images;
-  int index;
-  float rfsh;
+  NSUInteger index;
+  NSTimeInterval rfsh;
   NSTimer *progTimer;
   BOOL animating;
 }
 
 - (id)initWithFrame:(NSRect)frameRect 
-    refreshInterval:(float)refresh;
+    refreshInterval:(NSTimeInterval)refresh;
 
 - (void)start;
 
