@@ -1,8 +1,9 @@
 /* ImageViewer.m
  *  
- * Copyright (C) 2004 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2016 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
+ *         Riccardo Mottola <rm@gnu.org>
  * Date: January 2004
  *
  * This file is part of the GNUstep Inspector application
@@ -22,28 +23,21 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
-#include <AppKit/AppKit.h>
-#include "ImageViewer.h"
+#import <AppKit/AppKit.h>
+#import "ImageViewer.h"
 #include <math.h>
 
+#import "Resizer.h"
+
 @implementation ImageViewer
 
 - (void)dealloc
 {
-  [nc removeObserver: self];  
-
-  if (resizerConn != nil) {
-    if (resizer != nil) {
-      [resizer terminate];
-    }
-    DESTROY (resizer);    
-    DESTROY (resizerConn);
-  }
-
-  TEST_RELEASE (imagePath);	
-  TEST_RELEASE (image);	
-  TEST_RELEASE (nextPath);	
-  TEST_RELEASE (editPath);	
+  DESTROY (resizer);    
+  RELEASE (imagePath);	
+  RELEASE (image);	
+  RELEASE (nextPath);	
+  RELEASE (editPath);	
   RELEASE (extsarr);
   RELEASE (imview);
   RELEASE (errLabel);
@@ -134,13 +128,11 @@
 
     inspector = insp;
     fm = [NSFileManager defaultManager];
-    nc = [NSNotificationCenter defaultCenter];
     ws = [NSWorkspace sharedWorkspace];
         
     valid = YES;
     
     resizer = nil;
-    waitingResizer = NO;
     imagePath = nil;
     nextPath = nil;
     editPath = nil;
@@ -157,52 +149,41 @@
   DESTROY (editPath);
   [editButt setEnabled: NO];		
   
-  if (imagePath) {
-    ASSIGN (nextPath, path);
-    return;
-  }
+  if (imagePath)
+    {
+      ASSIGN (nextPath, path);
+      return;
+    }
   
   ASSIGN (imagePath, path);
 
-  if (conn == nil) {
-    NSString *cname = [NSString stringWithFormat: @"search_%i", (unsigned long)self];
+  if (conn == nil)
+    {
+      NSPort *p1;
+      NSPort *p2;  
 
-    conn = [[NSConnection alloc] initWithReceivePort: (NSPort *)[NSPort port] 
-																			      sendPort: nil];
-    [conn setRootObject: self];
-    [conn registerName: cname];
-    [conn setDelegate: self];
+      p1 = [NSPort port];
+      p2 = [NSPort port];
 
-    [nc addObserver: self
-           selector: @selector(connectionDidDie:)
-               name: NSConnectionDidDieNotification
-             object: conn];    
-  }
+      conn = [[NSConnection alloc] initWithReceivePort: p1 
+                                              sendPort: p2];
+      [conn setRootObject:self];
+
+      [NSThread detachNewThreadSelector: @selector(connectWithPorts:)
+                               toTarget: [ImageResizer class]
+                             withObject: [NSArray arrayWithObjects: p2, p1, nil]];   
+    }
   
-  if ((resizer == nil) && (waitingResizer == NO)) {
-    NSString *cname = [NSString stringWithFormat: @"search_%i", (unsigned long)self];
+  if (!(resizer == nil))
+    {
+      NSSize imsize = [imview bounds].size;
 
-    NSString *cmd = [NSTask launchPathForTool: @"resizer"];
-
-    waitingResizer = YES;
-
-    [NSTimer scheduledTimerWithTimeInterval: 5.0 
-						                         target: self
-                                   selector: @selector(checkResizer:) 
-																   userInfo: nil 
-                                    repeats: NO];
-
-    [NSTask launchedTaskWithLaunchPath: cmd 
-                             arguments: [NSArray arrayWithObject: cname]];
-  } else {
-    NSSize imsize = [imview bounds].size;
-    
-    imsize.width -= 4;
-    imsize.height -= 4;
-    [self addSubview: progView]; 
-    [progView start];
-    [resizer readImageAtPath: imagePath setSize: imsize];
-  }
+      imsize.width -= 4;
+      imsize.height -= 4;
+      [self addSubview: progView]; 
+      [progView start];
+      [resizer readImageAtPath: imagePath setSize: imsize];
+    }
 }
 
 - (void)displayLastPath:(BOOL)forced
@@ -217,138 +198,80 @@
   }
 }
 
-- (void)checkResizer:(id)sender
-{
-  if (waitingResizer && (resizer == nil)) {
-    NSRunAlertPanel(nil, 
-                    NSLocalizedString(@"unable to launch the resizer task.", @""), 
-                    NSLocalizedString(@"Continue", @""), 
-                    nil, 
-                    nil);
-  }
-}
-
 - (void)setResizer:(id)anObject
 {
-  if (resizer == nil) {
     NSSize imsize = [imview bounds].size;
-    
+
     imsize.width -= 4;
     imsize.height -= 4;
     [anObject setProtocolForProxy: @protocol(ImageResizerProtocol)];
-    resizer = (id <ImageResizerProtocol>)anObject;
+    resizer = (ImageResizer *)anObject;
     RETAIN (resizer);
-    waitingResizer = NO;
     [self addSubview: progView]; 
     [progView start];    
     [resizer readImageAtPath: imagePath setSize: imsize];
-  }
 }
 
-- (BOOL)connection:(NSConnection *)ancestor 
-								shouldMakeNewConnection:(NSConnection *)newConn
+
+
+- (void)imageReady:(NSDictionary *)imginfo
 {
-	if (ancestor == conn) {
-    ASSIGN (resizerConn, newConn);
-  	[resizerConn setDelegate: self];
-    
-  	[nc addObserver: self 
-					 selector: @selector(connectionDidDie:)
-	    				 name: NSConnectionDidDieNotification 
-             object: resizerConn];
-	}
-		
-  return YES;
-}
-
-- (void)connectionDidDie:(NSNotification *)notification
-{
-	id diedconn = [notification object];
-
-  [nc removeObserver: self
-	              name: NSConnectionDidDieNotification 
-              object: diedconn];
-
-  if ((diedconn == conn) || (resizerConn && (diedconn == resizerConn))) {
-    DESTROY (resizer);
-    DESTROY (resizerConn);
-    waitingResizer = NO;
-    
-    if ([[self subviews] containsObject: progView]) {
-      [progView stop];
-      [progView removeFromSuperview];  
-    }
-
-    if (diedconn == conn) {
-      DESTROY (conn);
-    } 
-    
-    DESTROY (imagePath);
-
-    NSRunAlertPanel(nil, 
-                    NSLocalizedString(@"resizer connection died.", @""), 
-                    NSLocalizedString(@"Continue", @""), 
-                    nil, 
-                    nil);
-  }
-}
-
-- (void)imageReady:(NSData *)data
-{
-  NSDictionary *imginfo = [NSUnarchiver unarchiveObjectWithData: data];
-  NSData *imgdata = [imginfo objectForKey: @"imgdata"];
-  BOOL imgok = YES;
+  NSData *imgdata;
+  BOOL imgok;
   NSString *lastPath;
-  
-  if ([self superview]) {      
-    [inspector contentsReadyAt: imagePath];
-  }
-        
-  if (imgdata) {
-    DESTROY (image);
-    image = [[NSImage alloc] initWithData: imgdata];
-    
-    if (image) {
-      float width = [[imginfo objectForKey: @"width"] floatValue];
-      float height = [[imginfo objectForKey: @"height"] floatValue];
-      NSString *str;
 
-      if (valid == NO) {
-        valid = YES;
-        [errLabel removeFromSuperview];
-        [self addSubview: imview]; 
-      }
+  if (imginfo == nil)
+    return;
 
-      [imview setImage: image];
-
-      str = NSLocalizedString(@"Width:", @"");
-      str = [NSString stringWithFormat: @"%@ %.0f", str, width];
-      [widthLabel setStringValue: str];
-
-      str = NSLocalizedString(@"Height:", @"");
-      str = [NSString stringWithFormat: @"%@ %.0f", str, height];
-      [heightLabel setStringValue: str];
-
-      ASSIGN (editPath, imagePath);
-      [editButt setEnabled: YES];		
-      [[self window] makeFirstResponder: editButt];
+  imgdata = [imginfo objectForKey:@"imgdata"];
+  imgok = NO;
+  if (imgdata)
+    {
+      if ([self superview])
+        [inspector contentsReadyAt: imagePath];
       
-    } else {
-      imgok = NO;
+      DESTROY (image);
+      image = [[NSImage alloc] initWithData: imgdata];
+
+      imgok = YES;
+      if (image)
+        {
+          float width = [[imginfo objectForKey: @"width"] floatValue];
+          float height = [[imginfo objectForKey: @"height"] floatValue];
+          NSString *str;
+
+          if (valid == NO)
+            {
+              valid = YES;
+              [errLabel removeFromSuperview];
+              [self addSubview: imview]; 
+            }
+
+          [imview setImage: image];
+
+          str = NSLocalizedString(@"Width:", @"");
+          str = [NSString stringWithFormat: @"%@ %.0f", str, width];
+          [widthLabel setStringValue: str];
+
+          str = NSLocalizedString(@"Height:", @"");
+          str = [NSString stringWithFormat: @"%@ %.0f", str, height];
+          [heightLabel setStringValue: str];
+
+          ASSIGN (editPath, imagePath);
+          [editButt setEnabled: YES];		
+          [[self window] makeFirstResponder: editButt];
+        }
     }
-    
-  } else {
-    imgok = NO;
-  }
+
   
   if (imgok == NO) {
     if (valid == YES) {
       valid = NO;
       [imview removeFromSuperview];
-			[self addSubview: errLabel];
+      [self addSubview: errLabel];
       [widthLabel setStringValue: @""];
       [heightLabel setStringValue: @""];
-			[editButt setEnabled: NO];		
+      [editButt setEnabled: NO];		
     }
   }
   
@@ -422,12 +345,12 @@
 
 - (void)editFile:(id)sender
 {
-	NSString *appName;
+  NSString *appName;
   NSString *type;
 
   [ws getInfoForFile: editPath application: &appName type: &type];
 
-	if (appName) {
+  if (appName) {
     NS_DURING
       {
     [ws openFile: editPath withApplication: appName];
@@ -450,7 +373,7 @@
   NSString *bpath = [[NSBundle bundleForClass: [self class]] bundlePath];
   NSString *resPath = [bpath stringByAppendingPathComponent: @"Resources"];
   NSArray *languages = [NSUserDefaults userLanguages];
-  unsigned i;
+  NSUInteger i;
      
   for (i = 0; i < [languages count]; i++) {
     NSString *language = [languages objectAtIndex: i];
@@ -483,17 +406,17 @@
 }
 
 - (id)initWithFrame:(NSRect)frameRect 
-    refreshInterval:(float)refresh
+    refreshInterval:(NSTimeInterval)refresh
 {
   self = [super initWithFrame: frameRect];
 
   if (self) {
-    int i;
+    NSUInteger i;
   
     images = [NSMutableArray new];
   
     for (i = 0; i < IMAGES; i++) {
-      NSString *imname = [NSString stringWithFormat: @"anim-logo-%d.tiff", i];
+      NSString *imname = [NSString stringWithFormat: @"anim-logo-%lu.tiff", (unsigned long)i];
       [images addObject: [NSImage imageNamed: imname]];    
     }
   
@@ -509,8 +432,8 @@
   index = 0;
   animating = YES;
   progTimer = [NSTimer scheduledTimerWithTimeInterval: rfsh 
-						            target: self selector: @selector(animate:) 
-																					userInfo: nil repeats: YES];
+                                               target: self selector: @selector(animate:) 
+                                             userInfo: nil repeats: YES];
 }
 
 - (void)stop
