@@ -19,12 +19,9 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
-#ifndef CONTENTVIEWERSPROTOCOL_H
-#define CONTENTVIEWERSPROTOCOL_H
-
 @protocol ContentViewersProtocol
 
 - (id)initWithFrame:(NSRect)frameRect
@@ -51,5 +48,4 @@
 
 @end 
 
-#endif // CONTENTVIEWERSPROTOCOL_H
 
