@@ -1,6 +1,6 @@
 /* Contents.m
  *  
- * Copyright (C) 2004-2013 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2016 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: January 2004
@@ -52,6 +52,7 @@ static NSString *nibName = @"Contents";
   RELEASE (currentPath);
   RELEASE (genericView);
   RELEASE (noContsView);
+  RELEASE (textViewer);
   RELEASE (mainBox);
   RELEASE (pboardImage);
       
@@ -113,15 +114,15 @@ static NSString *nibName = @"Contents";
 	      Class principalClass = [bundle principalClass];
 	    
 	      if ([principalClass conformsToProtocol: @protocol(ContentViewersProtocol)]) {	
-		      CREATE_AUTORELEASE_POOL (pool);
+                CREATE_AUTORELEASE_POOL (pool);
 		id vwr = [[principalClass alloc] initWithFrame: r inspector: self];
 	    
 		[viewers addObject: vwr];            
-		RELEASE ((id)vwr);	
+		[vwr release];	
 		RELEASE (pool);		
 	      }
 	    }
-		      }
+          }
 	}
     }
 
@@ -158,7 +159,7 @@ static NSString *nibName = @"Contents";
     NSImage *icon = [[FSNodeRep sharedInstance] multipleSelectionIconOfSize: ICNSIZE];
     NSString *items = NSLocalizedString(@"items", @"");
     
-    items = [NSString stringWithFormat: @"%i %@", [paths count], items];
+    items = [NSString stringWithFormat: @"%lu %@", (unsigned long)[paths count], items];
 		[titleField setStringValue: items];  
     [iconView setImage: icon];
     
@@ -176,42 +177,47 @@ static NSString *nibName = @"Contents";
 
 - (id)viewerForPath:(NSString *)path
 {
-	int i;
+  NSInteger i;
   
   if ((path == nil) || ([fm fileExistsAtPath: path] == NO)) {
     return nil;
   }
     
-	for (i = 0; i < [viewers count]; i++) {
-		id vwr = [viewers objectAtIndex: i];		
-		if ([vwr canDisplayPath: path]) {
-			return vwr;
-    }				
-	}
-
-	return nil;
+  for (i = 0; i < [viewers count]; i++)
+    {
+      id vwr = [viewers objectAtIndex: i];		
+      if ([vwr canDisplayPath: path])
+        {
+          return vwr;
+        }				
+    }
+  
+  return nil;
 }
 
 - (id)viewerForDataOfType:(NSString *)type
 {
-  int i;
+  NSInteger i;
   
-	for (i = 0; i < [viewers count]; i++) {
-		id vwr = [viewers objectAtIndex: i];		
-    
-    if ([vwr respondsToSelector: @selector(canDisplayDataOfType:)]) {
-      if ([vwr canDisplayDataOfType: type]) {
-			  return vwr;
-      }
-    } 				
-	}
+  for (i = 0; i < [viewers count]; i++)
+    {
+      id vwr = [viewers objectAtIndex: i];		
+      
+      if ([vwr respondsToSelector: @selector(canDisplayDataOfType:)])
+        {
+          if ([vwr canDisplayDataOfType: type])
+            {
+              return vwr;
+            }
+        } 				
+    }
   
   return nil;
 }
 
 - (void)showContentsAt:(NSString *)path
 {
-	NSString *winName;
+  NSString *winName;
 
   if (currentViewer) {
     if ([currentViewer respondsToSelector: @selector(stopTasks)]) {
@@ -219,8 +225,9 @@ static NSString *nibName = @"Contents";
     }
   }   
     	      
-	if (path && [fm fileExistsAtPath: path]) {
-		id viewer = [self viewerForPath: path];
+  if (path && [fm fileExistsAtPath: path])
+    {
+      id viewer = [self viewerForPath: path];
 
     if (currentPath && ([currentPath isEqual: path] == NO)) {
       [inspector removeWatcherForPath: currentPath];
@@ -662,9 +669,9 @@ static NSString *nibName = @"Contents";
                   value: [NSFont systemFontOfSize: 18] 
                   range: range];
 
-	[storage addAttribute: NSForegroundColorAttributeName 
-										value: [NSColor darkGrayColor] 
-										range: range];			
+  [storage addAttribute: NSForegroundColorAttributeName 
+                  value: [NSColor darkGrayColor] 
+                  range: range];			
 
   RELEASE (attrstr);
   RELEASE (style);
