@@ -1,6 +1,6 @@
 /* Inspector.h
  *  
- * Copyright (C) 2004 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2014 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: January 2004
@@ -25,24 +25,26 @@
 #ifndef INSPECTOR_H
 #define INSPECTOR_H
 
-#include <Foundation/Foundation.h>
-#include "FSNodeRep.h"
+#import <Foundation/Foundation.h>
+#import "FSNodeRep.h"
 
 @class Attributes;
 @class Contents;
 @class Tools;
 @class IconView;
+@class NSPopUpButton;
+@class NSWindow;
 
 @interface Inspector : NSObject 
 {
-  IBOutlet id win;
-  IBOutlet id popUp;
+  IBOutlet NSWindow *win;
+  IBOutlet NSPopUpButton *popUp;
   IBOutlet NSBox *inspBox;
 
   NSMutableArray *inspectors;
-	id currentInspector;
+  id currentInspector;
 
-	NSArray *currentPaths;
+  NSArray *currentPaths;
   NSString *watchedPath;
     
   NSNotificationCenter *nc; 
