@@ -1,6 +1,6 @@
 /* FileOpInfo.h
  *  
- * Copyright (C) 2004-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2014 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: March 2004
@@ -27,15 +27,19 @@
 
 @class FileOpExecutor;
 
+@class NSWindow;
+@class NSTextField;
+@class NSButton;
+@class NSProgressIndicator;
 
 @protocol FileOpInfoProtocol
 
 - (void)registerExecutor:(id)anObject;
                             
-- (int)requestUserConfirmationWithMessage:(NSString *)message 
+- (NSInteger)requestUserConfirmationWithMessage:(NSString *)message 
                                     title:(NSString *)title;
 
-- (int)showErrorAlertWithMessage:(NSString *)message;
+- (NSInteger)showErrorAlertWithMessage:(NSString *)message;
 
 - (void)setNumFiles:(int)n;
 
@@ -43,7 +47,11 @@
 
 - (void)sendDidChangeNotification;
 
-- (oneway void)endOperation;
+- (void)removeProcessedFiles;
+
+- (void)cleanUpExecutor;
+
+- (void)endOperation;
 
 @end
 
@@ -58,9 +66,9 @@
 
 - (BOOL)checkSameName;
 
-- (void)setOnlyOlder;
+- (void)setOnlyOlder:(BOOL)flag;
 
-- (oneway void)calculateNumFiles;
+- (oneway void)calculateNumFiles:(NSUInteger)continueFrom;
 
 - (oneway void)performOperation;
 
@@ -72,10 +80,6 @@
 
 - (BOOL)isPaused;
 
-- (void)done;
-
-- (oneway void)exitThread;
-
 @end
 
 
@@ -84,16 +88,18 @@
   NSString *type;
   NSString *source;
   NSString *destination;
-  NSArray *files;
+  NSMutableArray *files;
   NSMutableArray *dupfiles;
+  NSMutableArray *procFiles;
   int ref;
   
   NSMutableDictionary *operationDict;
   NSMutableArray *notifNames;
-  
+
   BOOL confirm;
   BOOL showwin;
   BOOL opdone;
+  BOOL onlyOlder;
   NSConnection *execconn;
   id <FileOpExecutorProtocol> executor;
   NSNotificationCenter *nc;
@@ -102,14 +108,14 @@
     
   id controller;  
 
-  IBOutlet id win;
-  IBOutlet id fromLabel;
-  IBOutlet id fromField;
-  IBOutlet id toLabel;
-  IBOutlet id toField;
+  IBOutlet NSWindow *win;
+  IBOutlet NSTextField *fromLabel;
+  IBOutlet NSTextField *fromField;
+  IBOutlet NSTextField *toLabel;
+  IBOutlet NSTextField *toField;
   IBOutlet NSProgressIndicator *progInd;
-  IBOutlet id pauseButt;
-  IBOutlet id stopButt;  
+  IBOutlet NSButton *pauseButt;
+  IBOutlet NSButton *stopButt;  
 }
 
 + (id)operationOfType:(NSString *)tp
@@ -134,10 +140,12 @@
 
 - (void)startOperation;
 
-- (int)requestUserConfirmationWithMessage:(NSString *)message 
+- (void)detachOperationThread;
+
+- (NSInteger)requestUserConfirmationWithMessage:(NSString *)message 
                                     title:(NSString *)title;
 
-- (int)showErrorAlertWithMessage:(NSString *)message;
+- (NSInteger)showErrorAlertWithMessage:(NSString *)message;
 
 - (IBAction)pause:(id)sender;
 
@@ -149,6 +157,10 @@
 
 - (void)setProgIndicatorValue:(int)n;
 
+- (void)removeProcessedFiles;
+
+- (void)cleanUpExecutor;
+
 - (void)endOperation;
 
 - (void)sendWillChangeNotification;
@@ -175,24 +187,24 @@
 
 - (NSWindow *)win;
 
-- (NSRect)winRect;
+- (void)getWinRect: (NSRect*)rptr;
 
 @end 
 
 
 @interface FileOpExecutor: NSObject
 {
-	NSString *operation;
-	NSString *source;
-	NSString *destination;
-	NSMutableArray *files;
-	NSMutableArray *procfiles;
-	NSDictionary *fileinfo;
-	NSString *filename;
+  NSString *operation;
+  NSString *source;
+  NSString *destination;
+  NSMutableArray *files;
+  NSMutableArray *procfiles;
+  NSDictionary *fileinfo;
+  NSString *filename;
   int fcount;
   float progstep;
   int stepcount;
-	BOOL canupdate;
+  BOOL canupdate;
   BOOL samename;
   BOOL onlyolder;
   NSFileManager *fm;
@@ -207,16 +219,12 @@
 
 - (BOOL)checkSameName;
 
-- (void)setOnlyOlder;
+- (oneway void)calculateNumFiles:(NSUInteger)continueFrom;
 
-- (void)calculateNumFiles;
-
-- (void)performOperation;
+- (oneway void)performOperation;
 
 - (NSData *)processedFiles;
 
-- (void)done;
-
 - (void)doMove;
 
 - (void)doCopy;
