@@ -1,6 +1,6 @@
 /* Operation.h
  *  
- * Copyright (C) 2004-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2013 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: March 2004
@@ -37,17 +37,17 @@ enum {
 @interface Operation : NSObject 
 {
   NSMutableArray *fileOperations;
-  int fopRef;
+  NSUInteger fopRef;
   
-  BOOL filenamesCutted;
+  BOOL filenamesCut;
     
   NSFileManager *fm;  
   NSNotificationCenter *nc; 
 }
 
-- (void)setFilenamesCutted:(BOOL)value;
+- (void)setFilenamesCut:(BOOL)value;
 
-- (BOOL)filenamesWasCutted;
+- (BOOL)filenamesWasCut;
 
 - (void)performOperation:(NSDictionary *)opdict;
 
@@ -60,9 +60,9 @@ enum {
                      
 - (void)endOfFileOperation:(FileOpInfo *)op;
 
-- (int)fileOpRef;
+- (NSUInteger)fileOpRef;
 
-- (FileOpInfo *)fileOpWithRef:(int)ref;
+- (FileOpInfo *)fileOpWithRef:(NSUInteger)ref;
 
 - (NSRect)rectForFileOpWindow;
 
