@@ -19,7 +19,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
 #ifndef START_APP_WIN
@@ -37,9 +37,9 @@
                  
 - (void)showWindowWithTitle:(NSString *)title
                     appName:(NSString *)appname
-               maxProgValue:(float)maxvalue;
+               maxProgValue:(double)maxvalue;
 
-- (void)updateProgressBy:(float)incr;
+- (void)updateProgressBy:(double)incr;
 
 - (NSWindow *)win;
 
