@@ -1,9 +1,9 @@
 /* fswatcher-inotify.m
  *  
- * Copyright (C) 2007-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2007-2015 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@fibernet.ro>
- * Date: Ianuary 2007
+ * Date: January 2007
  *
  * This file is part of the GNUstep GWorkspace application
  *
@@ -22,13 +22,17 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
-#include "fswatcher-inotify.h"
+#import "fswatcher-inotify.h"
 #include "config.h"
+#include <unistd.h>
 
 #define GWDebugLog(format, args...) \
   do { if (GW_DEBUG_LOG) \
     NSLog(format , ## args); } while (0)
 
+static BOOL	is_daemon = NO;		/* Currently running as daemon.	 */
+static BOOL	auto_stop = NO;		/* Should we shut down when unused? */
+
 static NSString *GWWatchedPathDeleted = @"GWWatchedPathDeleted";
 static NSString *GWFileDeletedInWatchedDirectory = @"GWFileDeletedInWatchedDirectory";
 static NSString *GWFileCreatedInWatchedDirectory = @"GWFileCreatedInWatchedDirectory";
@@ -50,12 +54,13 @@ static NSString *GWWatchedPathRenamed = @"GWWatchedPathRenamed";
 {
   self = [super init];
   
-  if (self) {
-		client = nil;
-		conn = nil;
-    wpaths = [[NSCountedSet alloc] initWithCapacity: 1];
-    global = NO;
-  }
+  if (self)
+    {
+      client = nil;
+      conn = nil;
+      wpaths = [[NSCountedSet alloc] initWithCapacity: 1];
+      global = NO;
+    }
   
   return self;
 }
@@ -117,17 +122,19 @@ static NSString *GWWatchedPathRenamed = @"GWWatchedPathRenamed";
 
 - (void)dealloc
 {
-  int i;
+  NSUInteger i;
 
-  for (i = 0; i < [clientsInfo count]; i++) {
-    NSConnection *connection = [[clientsInfo objectAtIndex: i] connection];
+  for (i = 0; i < [clientsInfo count]; i++)
+    {
+      NSConnection *connection = [[clientsInfo objectAtIndex: i] connection];
 
-		if (connection) {
-      [nc removeObserver: self
-		                name: NSConnectionDidDieNotification
-		              object: connection];
-		}
-  }
+      if (connection)
+	{
+	  [nc removeObserver: self
+			name: NSConnectionDidDieNotification
+		      object: connection];
+	}
+    }
   
   if (conn) {
     [nc removeObserver: self
@@ -153,30 +160,33 @@ static NSString *GWWatchedPathRenamed = @"GWWatchedPathRenamed";
 {
   self = [super init];
   
-  if (self) {    
-    int fd;
+  if (self)
+    {    
+      int fd;
 
-    fm = [NSFileManager defaultManager];	
-    nc = [NSNotificationCenter defaultCenter];
-    dnc = [NSDistributedNotificationCenter defaultCenter];
-               
-    conn = [NSConnection defaultConnection];
-    [conn setRootObject: self];
-    [conn setDelegate: self];
+      fm = [NSFileManager defaultManager];	
+      nc = [NSNotificationCenter defaultCenter];
+      dnc = [NSDistributedNotificationCenter defaultCenter];
+      
+      conn = [NSConnection defaultConnection];
+      [conn setRootObject: self];
+      [conn setDelegate: self];
     
-    if ([conn registerName: @"fswatcher"] == NO) {
-	    NSLog(@"unable to register with name server.");
-	    DESTROY (self);
-	    return self;
-	  }
+      if ([conn registerName: @"fswatcher"] == NO)
+	{
+	  NSLog(@"unable to register with name server.");
+	  DESTROY (self);
+	  return self;
+	}
 
-    fd = inotify_init();  
+      fd = inotify_init();  
   
-    if (fd == -1) {
-      NSLog(@"inotify_init() failed!");
-      DESTROY (self);
-      return self;  
-    }
+      if (fd == -1)
+	{
+	  NSLog(@"inotify_init() failed!");
+	  DESTROY (self);
+	  return self;  
+	}
     
     inotifyHandle = [[NSFileHandle alloc] initWithFileDescriptor: fd 
                                                   closeOnDealloc: YES];  
@@ -255,36 +265,48 @@ static NSString *GWWatchedPathRenamed = @"GWWatchedPathRenamed";
 	              name: NSConnectionDidDieNotification
 	            object: connection];
 
-  if (connection == conn) {
-    NSLog(@"argh - fswatcher server root connection has been destroyed.");
-    exit(EXIT_FAILURE);
-    
-  } else {
-		FSWClientInfo *info = [self clientInfoWithConnection: connection];
-	
-		if (info) {
-      NSSet *wpaths = [info watchedPaths];
-      NSEnumerator *enumerator = [wpaths objectEnumerator];
-      NSString *wpath;
+  if (connection == conn)
+    {
+      NSLog(@"argh - fswatcher server root connection has been destroyed.");
+      exit(EXIT_FAILURE);  
+    }
+  else
+    {
+      FSWClientInfo *info = [self clientInfoWithConnection: connection];
       
-      while ((wpath = [enumerator nextObject])) {
-        Watcher *watcher = [self watcherForPath: wpath];
-      
-        if (watcher) {
-          [watcher removeListener];
-        }      
-      }
-          
-			[clientsInfo removeObject: info];
-		}
+      if (info)
+	{
+	  NSSet *wpaths = [info watchedPaths];
+	  NSEnumerator *enumerator = [wpaths objectEnumerator];
+	  NSString *wpath;
+	  
+	  while ((wpath = [enumerator nextObject]))
+	    {
+	      Watcher *watcher = [self watcherForPath: wpath];
+	      
+	      if (watcher)
+		[watcher removeListener];
+	    }
+	  
+	  [clientsInfo removeObject: info];
 	}
+      
+      if (auto_stop == YES && [clientsInfo count] <= 1)
+	{
+	  /* If there is nothing else using this process, and this is not
+	   * a daemon, then we can quietly terminate.
+	   */
+	  NSLog(@"No more clients, shutting down.");
+	  exit(EXIT_SUCCESS);
+	}
+    }
 }
 
 - (void)setDefaultGlobalPaths
 {
   NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
   id entry;
-  unsigned i;
+  NSUInteger i;
   
   [defaults synchronize];
 
@@ -351,7 +373,7 @@ static NSString *GWWatchedPathRenamed = @"GWWatchedPathRenamed";
   NSArray *excluded = [info objectForKey: @"GSMetadataExcludedPaths"];
   NSArray *suffixes = [info objectForKey: @"GSMetadataExcludedSuffixes"];
   
-  unsigned i;
+  NSUInteger i;
 
   emptyTreeWithBase(includePathsTree);
   
@@ -372,19 +394,21 @@ static NSString *GWWatchedPathRenamed = @"GWWatchedPathRenamed";
 - (oneway void)registerClient:(id <FSWClientProtocol>)client
               isGlobalWatcher:(BOOL)global
 {
-	NSConnection *connection = [(NSDistantObject *)client connectionForProxy];
+  NSConnection *connection = [(NSDistantObject *)client connectionForProxy];
   FSWClientInfo *info = [self clientInfoWithConnection: connection];
 
-	if (info == nil) {
-    [NSException raise: NSInternalInconsistencyException
-		            format: @"registration with unknown connection"];
-  }
-
-  if ([info client] != nil) { 
-    [NSException raise: NSInternalInconsistencyException
-		            format: @"registration with registered client"];
-  }
+  if (info == nil)
+    {
+      [NSException raise: NSInternalInconsistencyException
+		  format: @"registration with unknown connection"];
+    }
 
+  if ([info client] != nil)
+    { 
+      [NSException raise: NSInternalInconsistencyException
+		  format: @"registration with registered client"];
+    }
+  
   if ([(id)client isProxy] == YES) {
     [(id)client setProtocolForProxy: @protocol(FSWClientProtocol)];
     [info setClient: client];  
@@ -394,13 +418,13 @@ static NSString *GWWatchedPathRenamed = @"GWWatchedPathRenamed";
 
 - (oneway void)unregisterClient:(id <FSWClientProtocol>)client
 {
-	NSConnection *connection = [(NSDistantObject *)client connectionForProxy];
+  NSConnection *connection = [(NSDistantObject *)client connectionForProxy];
   FSWClientInfo *info = [self clientInfoWithConnection: connection];
   NSSet *wpaths;
   NSEnumerator *enumerator;
   NSString *wpath;
 
-	if (info == nil) {
+  if (info == nil) {
     [NSException raise: NSInternalInconsistencyException
 		            format: @"unregistration with unknown connection"];
   }
@@ -425,12 +449,20 @@ static NSString *GWWatchedPathRenamed = @"GWWatchedPathRenamed";
 	              name: NSConnectionDidDieNotification
 	            object: connection];
 
-  [clientsInfo removeObject: info];  
+  [clientsInfo removeObject: info];
+  
+  if (auto_stop == YES && [clientsInfo count] <= 1)
+    {
+      /* If there is nothing else using this process, and this is not
+       * a daemon, then we can quietly terminate.
+       */
+      exit(EXIT_SUCCESS);
+    }
 }
 
 - (FSWClientInfo *)clientInfoWithConnection:(NSConnection *)connection
 {
-  int i;
+  NSUInteger i;
 
   for (i = 0; i < [clientsInfo count]; i++) {
     FSWClientInfo *info = [clientsInfo objectAtIndex: i];
@@ -445,27 +477,27 @@ static NSString *GWWatchedPathRenamed = @"GWWatchedPathRenamed";
 
 - (FSWClientInfo *)clientInfoWithRemote:(id)remote
 {
-  int i;
+  NSUInteger i;
 
-  for (i = 0; i < [clientsInfo count]; i++) {
-    FSWClientInfo *info = [clientsInfo objectAtIndex: i];
+  for (i = 0; i < [clientsInfo count]; i++)
+    {
+      FSWClientInfo *info = [clientsInfo objectAtIndex: i];
+      
+      if ([info client] == remote)
+	return info;
+    }
   
-		if ([info client] == remote) {
-			return info;
-		}
-  }
-
-	return nil;
+  return nil;
 }
 
 - (oneway void)client:(id <FSWClientProtocol>)client
                               addWatcherForPath:(NSString *)path
 {
-	NSConnection *connection = [(NSDistantObject *)client connectionForProxy];
+  NSConnection *connection = [(NSDistantObject *)client connectionForProxy];
   FSWClientInfo *info = [self clientInfoWithConnection: connection];
   Watcher *watcher = [self watcherForPath: path];
 
-	if (info == nil) {
+  if (info == nil) {
     [NSException raise: NSInternalInconsistencyException
 		            format: @"adding watcher from unknown connection"];
   }
@@ -511,7 +543,7 @@ static NSString *GWWatchedPathRenamed = @"GWWatchedPathRenamed";
 - (oneway void)client:(id <FSWClientProtocol>)client
                                 removeWatcherForPath:(NSString *)path
 {
-	NSConnection *connection = [(NSDistantObject *)client connectionForProxy];
+  NSConnection *connection = [(NSDistantObject *)client connectionForProxy];
   FSWClientInfo *info = [self clientInfoWithConnection: connection];
   Watcher *watcher = [self watcherForPath: path];
   
@@ -568,7 +600,7 @@ static NSString *GWWatchedPathRenamed = @"GWWatchedPathRenamed";
   CREATE_AUTORELEASE_POOL(pool);
   NSString *path = [info objectForKey: @"path"];
   NSData *data = [NSArchiver archivedDataWithRootObject: info];
-  int i;
+  NSUInteger i;
 
   for (i = 0; i < [clientsInfo count]; i++) {
     FSWClientInfo *clinfo = [clientsInfo objectAtIndex: i];
@@ -583,7 +615,7 @@ static NSString *GWWatchedPathRenamed = @"GWWatchedPathRenamed";
 
 - (void)notifyGlobalWatchingClients:(NSDictionary *)info
 {
-  int i;
+  NSUInteger i;
 
   for (i = 0; i < [clientsInfo count]; i++) {
     FSWClientInfo *clinfo = [clientsInfo objectAtIndex: i];
@@ -1046,11 +1078,17 @@ int main(int argc, char** argv)
   static BOOL	is_daemon = NO;
   BOOL subtask = YES;
 
-  if ([[info arguments] containsObject: @"--daemon"]) {
+  if ([[info arguments] containsObject: @"--auto"] == YES)
+  {
+    auto_stop = YES;
+  }
+    
+  if ([[info arguments] containsObject: @"--daemon"])
+  {
     subtask = NO;
     is_daemon = YES;
   }
-
+  
   if (subtask) {
     NSTask *task = [NSTask new];
     
