@@ -1,6 +1,6 @@
 /* searchtool.m
  *  
- * Copyright (C) 2004 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2016 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: February 2004
@@ -22,10 +22,10 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
-#include <Foundation/Foundation.h>
-#include <AppKit/AppKit.h>
-#include "FinderModulesProtocol.h"
-#include "config.h"
+#import <Foundation/Foundation.h>
+#import <AppKit/AppKit.h>
+#import "FinderModulesProtocol.h"
+#import "config.h"
 
 
 
@@ -89,7 +89,7 @@
 - (void)dealloc
 {
   [nc removeObserver: self];
-	DESTROY (finder);
+  DESTROY (finder);
   DESTROY (ddbd);
   [super dealloc];
 }
@@ -109,7 +109,7 @@
     
     if (conn == nil) {
       NSLog(@"failed to contact Finder - bye.");
-	    exit(1);           
+      exit(1);           
     } 
 
     [nc addObserver: self
@@ -136,8 +136,8 @@
   id conn = [notification object];
 
   [nc removeObserver: self
-	              name: NSConnectionDidDieNotification
-	            object: conn];
+		name: NSConnectionDidDieNotification
+  	      object: conn];
 
   if (done == NO) {
     NSLog(@"finder connection has been destroyed.");
@@ -150,8 +150,8 @@
   CREATE_AUTORELEASE_POOL(arp);
   NSDictionary *srcdict = [NSUnarchiver unarchiveObjectWithData: srcinfo];
   NSArray *paths = [srcdict objectForKey: @"paths"];
-  id recursion = [srcdict objectForKey: @"recursion"];
-  BOOL norecursion = ((recursion != nil) && ([recursion boolValue] == NO));
+  id recursionObj = [srcdict objectForKey: @"recursion"];
+  BOOL recursion;
   NSDictionary *criteria = [srcdict objectForKey: @"criteria"];
   NSArray *classNames = [criteria allKeys];
   NSMutableArray *modules = [NSMutableArray array];
@@ -159,7 +159,11 @@
   BOOL isdir;
   NSMutableArray *bundlesPaths;
   NSEnumerator *enumerator;
-  int i;
+  NSUInteger i;
+
+  recursion = NO;
+  if (recursionObj)
+      recursion = [recursionObj boolValue];
 
   bundlesPaths = [NSMutableArray array];
   enumerator = [NSSearchPathForDirectoriesInDomains
@@ -184,7 +188,7 @@
     NSBundle *bundle = [NSBundle bundleWithPath: bpath];
      
     if (bundle) {
-			Class principalClass = [bundle principalClass];
+      Class principalClass = [bundle principalClass];
       NSString *className = NSStringFromClass(principalClass);
 
       if ([classNames containsObject: className]) {
@@ -201,13 +205,13 @@
     NSString *path = [paths objectAtIndex: i];
     NSDictionary *attributes = [fm fileAttributesAtPath: path traverseLink: YES];
     NSString *type = [attributes fileType];
-    int j;
+    NSUInteger j;
     
     if (type == NSFileTypeDirectory) {
       CREATE_AUTORELEASE_POOL(arp1);
       NSDirectoryEnumerator *enumerator = [fm enumeratorAtPath: path];
       
-      while (1) {
+      while (!stopped) {
         CREATE_AUTORELEASE_POOL(arp2);
         NSString *currentPath = [enumerator nextObject];
       
@@ -239,7 +243,7 @@
             break;
           }
 
-          if (([attrs fileType] == NSFileTypeDirectory) && norecursion) {
+          if (([attrs fileType] == NSFileTypeDirectory) && !recursion) {
             [enumerator skipDescendents];
           }
         
@@ -301,7 +305,7 @@
 }
 
 - (NSArray *)bundlesWithExtension:(NSString *)extension 
-													 inPath:(NSString *)path
+			   inPath:(NSString *)path
 {
   NSMutableArray *bundleList = [NSMutableArray array];
   NSEnumerator *enumerator;
@@ -309,14 +313,14 @@
   BOOL isDir;
   
   if ((([fm fileExistsAtPath: path isDirectory: &isDir]) && isDir) == NO) {
-		return nil;
+    return nil;
   }
 	  
   enumerator = [[fm directoryContentsAtPath: path] objectEnumerator];
   while ((dir = [enumerator nextObject])) {
     if ([[dir pathExtension] isEqualToString: extension]) {
-			[bundleList addObject: [path stringByAppendingPathComponent: dir]];
-		}
+      [bundleList addObject: [path stringByAppendingPathComponent: dir]];
+    }
   }
   
   return bundleList;
@@ -334,7 +338,7 @@
                                                              host: @""];
 
     if (ddbd == nil) {
-	    NSString *cmd;
+      NSString *cmd;
       int i;
     
       cmd = [NSTask launchPathForTool: @"ddbd"];    
@@ -343,7 +347,7 @@
    
       for (i = 0; i < 40; i++) {
         [[NSRunLoop currentRunLoop] runUntilDate:
-		                       [NSDate dateWithTimeIntervalSinceNow: 0.1]];
+            [NSDate dateWithTimeIntervalSinceNow: 0.1]];
 
         ddbd = [NSConnection rootProxyForConnectionWithRegisteredName: @"ddbd" 
                                                                  host: @""];                  
@@ -357,10 +361,10 @@
       RETAIN (ddbd);
       [ddbd setProtocolForProxy: @protocol(DDBd)];
     
-	    [[NSNotificationCenter defaultCenter] addObserver: self
-	                   selector: @selector(ddbdConnectionDidDie:)
-		                     name: NSConnectionDidDieNotification
-		                   object: [ddbd connectionForProxy]];
+      [[NSNotificationCenter defaultCenter] addObserver: self
+					       selector: @selector(ddbdConnectionDidDie:)
+		                     		   name: NSConnectionDidDieNotification
+		                   		 object: [ddbd connectionForProxy]];
                        
     } else {
       NSLog(@"unable to contact ddbd.");
@@ -373,11 +377,11 @@
   id connection = [notif object];
 
   [nc removeObserver: self
-	              name: NSConnectionDidDieNotification
-	            object: connection];
+		name: NSConnectionDidDieNotification
+	      object: connection];
 
   NSAssert(connection == [ddbd connectionForProxy],
-		                                  NSInternalInconsistencyException);
+		NSInternalInconsistencyException);
   RELEASE (ddbd);
   ddbd = nil;
 }
@@ -413,6 +417,3 @@ int main(int argc, char** argv)
   exit(0);
 }
 
-
-
-
